Module builtin

Module builtin 

Built-in resource is a resource embedded in the application executable file. It is a very useful mechanism when you need to bundle all game resources and put them in the executable file. See BuiltInResource docs for more info.

Structs

BuiltInResource
Built-in resource is a resource embedded in the application executable file. It is a very useful mechanism when you need to bundle all game resources and put them in the executable file.
BuiltInResourcesContainer
A container for built-in resources. Every built-in resource is registered using its id defined at the creation stage.
DataSource
Data source of a built-in resource.
UntypedBuiltInResource
Untyped built-in resource.