pub struct ResourceEventBroadcaster { /* private fields */ }Expand description
Event broadcaster is responsible for delivering resource events to “subscribers”.
Implementations
Sourceimpl ResourceEventBroadcaster
impl ResourceEventBroadcaster
Sourcepub fn new() -> ResourceEventBroadcaster
pub fn new() -> ResourceEventBroadcaster
Creates new empty event broadcaster.
Sourcepub fn add(
&self,
sender: Sender<ResourceEvent>,
) -> Handle<Sender<ResourceEvent>>
pub fn add( &self, sender: Sender<ResourceEvent>, ) -> Handle<Sender<ResourceEvent>>
Adds an event sender to the broadcaster and returns its handle. If the receiver part of the channel dies, the sender part is automatically removed from the broadcaster.
Sourcepub fn remove(
&self,
handle: Handle<Sender<ResourceEvent>>,
) -> Sender<ResourceEvent>
pub fn remove( &self, handle: Handle<Sender<ResourceEvent>>, ) -> Sender<ResourceEvent>
Removes an event sender by its handle.
Sourcepub fn broadcast(&self, event: ResourceEvent)
pub fn broadcast(&self, event: ResourceEvent)
Sends an event to all “subscribers” in the broadcaster.
Sourcepub fn broadcast_loaded(&self, resource: UntypedResource)
pub fn broadcast_loaded(&self, resource: UntypedResource)
Sends a ResourceEvent::Loaded event to all “subscribers” in the broadcaster.
Sourcepub fn broadcast_loaded_or_reloaded(
&self,
resource: UntypedResource,
reload: bool,
)
pub fn broadcast_loaded_or_reloaded( &self, resource: UntypedResource, reload: bool, )
Sends either a ResourceEvent::Loaded event or a ResourceEvent::Reloaded to all
“subscribers” in the broadcaster depending on the reload parameter.