pub trait FileReader:
Debug
+ Send
+ Sync
+ Read
+ Seek
+ 'static {
// Required method
fn byte_len(&self) -> Option<u64>;
}Expand description
Trait for files readers ensuring they implement the required traits
pub trait FileReader:
Debug
+ Send
+ Sync
+ Read
+ Seek
+ 'static {
// Required method
fn byte_len(&self) -> Option<u64>;
}Trait for files readers ensuring they implement the required traits