Module manager

Module manager 

Resource manager controls loading and lifetime of resource in the engine. See ResourceManager docs for more info.

Structs

BuiltInResource
Built-in resource is a resource embedded in the application executable file. It is a very useful mechanism when you need to bundle all game resources and put them in the executable file.
BuiltInResourcesContainer
A container for built-in resources. Every built-in resource is registered using its id defined at the creation stage.
DataSource
Data source of a built-in resource.
ResourceManager
Resource manager controls loading and lifetime of resource in the engine. Resource manager can hold resources of arbitrary types via type erasure mechanism.
ResourceManagerState
Internal state of the resource manager.
ResourceMoveContext
All the required and validated data that is needed to move a resource from the path A to the path B.
ResourceWaitContext
A set of resources that can be waited for.
UntypedBuiltInResource
Untyped built-in resource.

Enums

FolderMovementError
A set of potential errors that may occur when moving a folder with resources.
ResourceMovementError
A possible set of errors that may occur during resource movement.
ResourceRegistrationError
An error that may occur during texture registration.