Module metadata

Module metadata 

Resource metadata. See ResourceMetadata docs for more info.

Structs

ResourceMetadata
Resource metadata contains additional information that cannot be stored in the resource file itself. The most important bit of information is a resource uuid, this id is used to as reference that does not change when the resource moved or renamed.