pub enum TileConstraint<T, P> {
None,
Terrain(T),
Pattern(P),
}Expand description
The ways in which a cell’s choice of tile can be constrained.
Variants
None
No constraint. This means that the cell is outside of the area of consideration for the autotiler, such as beyond the edge of the world. Cells with this constraint put no limits on what may be adjacent in any direction.
Terrain(T)
A terrain is a set of possible patterns. Any pattern within the terrain may be chosen to be the pattern for this cell.
Pattern(P)
A pattern constraint means that the pattern for this cell has already been chosen and may not change.
Implementations
Sourceimpl<T, P> TileConstraint<T, P>
impl<T, P> TileConstraint<T, P>
Sourcepub fn is_none(&self) -> bool
pub fn is_none(&self) -> bool
True if this is the None constraint that does not restrict which pattern may be chosen.
Sourcepub fn is_some(&self) -> bool
pub fn is_some(&self) -> bool
True if this constraint is not None, meaning it is either a pattern or a terrain.
Sourcepub fn is_terrain(&self) -> bool
pub fn is_terrain(&self) -> bool
True if this constraint is a terrain, meaning there are zero or more permitted patterns.
Sourcepub fn is_pattern(&self) -> bool
pub fn is_pattern(&self) -> bool
Tue if this contraint is a pattern, meaning that only that exact pattern is permitted.
Sourcepub fn all_patterns(&self) -> TileConstraint<impl Iterator<Item = &P>, &P> ⓘwhere
T: TileTerrain<Pattern = P>,
pub fn all_patterns(&self) -> TileConstraint<impl Iterator<Item = &P>, &P> ⓘwhere
T: TileTerrain<Pattern = P>,
An iterator over all the patterns explicitly permitted by this contraint,
or an empty iterator if the constraint is None.
The None constraint permits any pattern, but it is not possible to create
an interator over all patterns here, so all_patterns should usually only
be called if is_some returns true.