pub struct ListTerrain<'a, P>(pub &'a [P]);Expand description
An implementation of TileTerrain based upon a slice of patterns.
Tuple Fields
0: &'a [P]Trait Implementations
Sourceimpl<'a, P> Clone for ListTerrain<'a, P>where
P: Clone,
impl<'a, P> Clone for ListTerrain<'a, P>where
P: Clone,
Sourcefn clone(&self) -> ListTerrain<'a, P>
fn clone(&self) -> ListTerrain<'a, P>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, P> Debug for ListTerrain<'a, P>where
P: Debug,
impl<'a, P> Debug for ListTerrain<'a, P>where
P: Debug,
Sourceimpl<P> TileTerrain for ListTerrain<'_, P>
impl<P> TileTerrain for ListTerrain<'_, P>
Sourcefn all_patterns(&self) -> impl Iterator<Item = &P>
fn all_patterns(&self) -> impl Iterator<Item = &P>
Iterate through the patterns within the terrain in the order of priority.
The autotiler will proceed through this iterator until it finds a pattern
that is legal according to the constraints, then ignore any remaining patterns.