AbstractRotation

Trait AbstractRotation 

pub trait AbstractRotation<T, const D: usize>:
    PartialEq
    + ClosedMulAssign
    + Clone
where T: Scalar,
{ // Required methods fn identity() -> Self; fn inverse(&self) -> Self; fn inverse_mut(&mut self); fn transform_vector( &self, v: &Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>, ) -> Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>; fn transform_point(&self, p: &OPoint<T, Const<D>>) -> OPoint<T, Const<D>>; fn inverse_transform_vector( &self, v: &Matrix<T, Const<D>, Const<1>, <DefaultAllocator as Allocator<Const<D>>>::Buffer<T>>, ) -> Matrix<T, Const<D>, Const<1>, <DefaultAllocator as Allocator<Const<D>>>::Buffer<T>>; fn inverse_transform_point( &self, p: &OPoint<T, Const<D>>, ) -> OPoint<T, Const<D>>; // Provided method fn inverse_transform_unit_vector( &self, v: &Unit<Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>>, ) -> Unit<Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>> { ... } }
Trait implemented by rotations that can be used inside of an Isometry or Similarity.

Required Methods

fn identity() -> Self

The rotation identity.

fn inverse(&self) -> Self

The rotation inverse.

fn inverse_mut(&mut self)

Change self to its inverse.

fn transform_vector( &self, v: &Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>, ) -> Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>

Apply the rotation to the given vector.

fn transform_point(&self, p: &OPoint<T, Const<D>>) -> OPoint<T, Const<D>>

Apply the rotation to the given point.

fn inverse_transform_vector( &self, v: &Matrix<T, Const<D>, Const<1>, <DefaultAllocator as Allocator<Const<D>>>::Buffer<T>>, ) -> Matrix<T, Const<D>, Const<1>, <DefaultAllocator as Allocator<Const<D>>>::Buffer<T>>

Apply the inverse rotation to the given vector.

fn inverse_transform_point( &self, p: &OPoint<T, Const<D>>, ) -> OPoint<T, Const<D>>

Apply the inverse rotation to the given point.

Provided Methods

fn inverse_transform_unit_vector( &self, v: &Unit<Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>>, ) -> Unit<Matrix<T, Const<D>, Const<1>, ArrayStorage<T, D, 1>>>

Apply the inverse rotation to the given unit vector.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors