ReflectInheritableVariable

Trait ReflectInheritableVariable 

pub trait ReflectInheritableVariable: Reflect {
    // Required methods
    fn try_inherit(
        &mut self,
        parent: &(dyn ReflectInheritableVariable + 'static),
        ignored_types: &[TypeId],
    ) -> Result<Option<Box<dyn Reflect>>, InheritError>;
    fn reset_modified_flag(&mut self);
    fn flags(&self) -> VariableFlags;
    fn set_flags(&mut self, flags: VariableFlags);
    fn is_modified(&self) -> bool;
    fn value_equals(
        &self,
        other: &(dyn ReflectInheritableVariable + 'static),
    ) -> bool;
    fn clone_value_box(&self) -> Box<dyn Reflect>;
    fn mark_modified(&mut self);
    fn inner_value_mut(&mut self) -> &mut (dyn Reflect + 'static);
    fn inner_value_ref(&self) -> &(dyn Reflect + 'static);
}

Required Methods

fn try_inherit( &mut self, parent: &(dyn ReflectInheritableVariable + 'static), ignored_types: &[TypeId], ) -> Result<Option<Box<dyn Reflect>>, InheritError>

Tries to inherit a value from parent. It will succeed only if the current variable is not marked as modified.

fn reset_modified_flag(&mut self)

Resets modified flag from the variable.

fn flags(&self) -> VariableFlags

Returns current variable flags.

fn set_flags(&mut self, flags: VariableFlags)

fn is_modified(&self) -> bool

Returns true if value was modified.

fn value_equals( &self, other: &(dyn ReflectInheritableVariable + 'static), ) -> bool

Returns true if value equals to other’s value.

fn clone_value_box(&self) -> Box<dyn Reflect>

Clones self value.

fn mark_modified(&mut self)

Marks value as modified, so its value won’t be overwritten during property inheritance.

fn inner_value_mut(&mut self) -> &mut (dyn Reflect + 'static)

Returns a mutable reference to wrapped value without marking the variable itself as modified.

fn inner_value_ref(&self) -> &(dyn Reflect + 'static)

Returns a shared reference to wrapped value without marking the variable itself as modified.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors