Module field

Module field 

A set fundamental data types.

Structs

Field
Values within a visitor are constructed from Fields. Each Field has a name and a value. The name is used as a key to access the value within the visitor using the crate::Visit::visit method, so each field within a value must have a unique name.

Enums

FieldKind
The internal data format of crate::visitor::Visitor. Fields are limited to being one of these types. This means that all crate::visitor::Visit values must be built from some assortment of these types. Fields can be accessed from a visitor using crate::visitor::Visit::visit on a variable with the same type as the field.