pub struct BlendAnimationsByIndex<T>where
T: EntityId,{
pub base: BasePoseNode<T>,
pub index_parameter: String,
pub inputs: Vec<IndexedBlendInput<T>>,
pub prev_index: Cell<Option<u32>>,
pub blend_time: Cell<f32>,
pub output_pose: RefCell<AnimationPose<T>>,
}Expand description
A node that switches between given animations using index and smoothly blends from one animation to another
while switching. It is very useful for situations when you need to switch between different animations. For
example you could have an aim state, it is suitable for any weapon (you don’t need to create a ton of states
like aim_rifle, aim_pistol, etc), but actual weapon holding animation should be different based on actual
weapon a character is holding. In this case you create a BlendAnimationsByIndex node, add a few inputs where
each input uses different weapon holding animation and in your game all you need to do is to set an index
parameter in the machine parameters. The node will automatically perform smooth transition between different
animations.
Fields
base: BasePoseNode<T>Base node.
index_parameter: StringA name of index parameter that will be used to switch between input poses.
inputs: Vec<IndexedBlendInput<T>>A set of input poses.
prev_index: Cell<Option<u32>>Index of a previously active input pose.
blend_time: Cell<f32>Current blend time.
output_pose: RefCell<AnimationPose<T>>Output pose of the node.
Implementations
Sourceimpl<T> BlendAnimationsByIndex<T>where
T: EntityId,
impl<T> BlendAnimationsByIndex<T>where
T: EntityId,
Sourceimpl<T> BlendAnimationsByIndex<T>where
T: EntityId,
impl<T> BlendAnimationsByIndex<T>where
T: EntityId,
Sourcepub fn new(
index_parameter: String,
inputs: Vec<IndexedBlendInput<T>>,
) -> BlendAnimationsByIndex<T>
pub fn new( index_parameter: String, inputs: Vec<IndexedBlendInput<T>>, ) -> BlendAnimationsByIndex<T>
Creates new BlendAnimationsByIndex node using given index parameter name and a set of inputs.