Crate graph

Crate graph 

Graph utilities and common algorithms.

Modules

constructor
prelude

Structs

GraphTraverseIterator
Iterator that traverses tree in depth and returns shared references to nodes.
LinkScheme
NodeHandleMap
A OriginalHandle -> CopyHandle map. It is used to map handles to nodes after copying.

Enums

NodeMapping

Traits

AbstractSceneGraph
AbstractSceneNode
BaseSceneGraph
BaseSceneGraph is a dyn-compatible trait for all scene graphs to implement. Methods that would not be dyn-compatible are available through the SceneGraph trait.
PrefabData
SceneGraph
SceneGraph is a non-dyn-compatible trait for all scene graphs to implement. To use a scene graph as a dyn object, use dyn BaseSceneGraph because BaseSceneGraph is dyn-compatible.
SceneGraphNode