image_1d_size_bytes

Function image_1d_size_bytes 

pub fn image_1d_size_bytes(pixel_kind: PixelKind, length: usize) -> usize
Calculates size in bytes of a linear texture using the given size of the texture and its pixel kind.