A sampler is a GPU entity that defines how texels will be fetched from a texture. See GpuSamplerDescriptor
docs for more info.
Structs
- GpuSampler
Descriptor - A set of potential options that can be used to configure a GPU sampler.
Enums
- Coordinate
- Texture coordinate.
- Magnification
Filter - The texture magnification function is used when the pixel being textured maps to an area less than or equal to one texture element.
- Minification
Filter - The texture minifying function is used whenever the pixel being textured maps to an area greater than one texture element.
- Wrap
Mode - Defines a law of texture coordinate modification.
Traits
- GpuSampler
AsAny - A base trait that provides useful methods for trait downcasting.
- GpuSampler
Trait - Sampler is a GPU entity that defines how texels will be fetched from a texture. See
GpuSamplerDescriptordocs for more info.