pub trait GpuSamplerTrait: GpuSamplerAsAny + Debug { }Expand description
Sampler is a GPU entity that defines how texels will be fetched from a texture. See GpuSamplerDescriptor
docs for more info.
pub trait GpuSamplerTrait: GpuSamplerAsAny + Debug { }Sampler is a GPU entity that defines how texels will be fetched from a texture. See GpuSamplerDescriptor
docs for more info.