Uniform buffer is a special byte storage that ensures correct data alignment suitable for GPU.
Current implementation supports std140 data layout scheme.
Structs
- Uniform
Buffer - Uniform buffer is a special byte storage that ensures correct data alignment suitable for GPU.
Current implementation supports
std140data layout scheme.
Traits
- Byte
Storage - A trait for any storage suitable to store bytes for uniforms.
- Std140
- A trait for entities that supports
std140data layout.
Type Aliases
- Dynamic
Uniform Buffer - A uniform buffer backed by a dynamic array.
- Static
Uniform Buffer - A uniform buffer backed by an array of fixed size.