Module server

Module server 

Structs

GlGraphicsServer
GlGraphicsServer implements the GraphicsServer trait using the glow crate. glow is “GL on Whatever: a set of bindings to run GL anywhere (Open GL, OpenGL ES, and WebGL) and avoid target-specific code.”

Enums

FrameBufferBindingPoint
A frame buffer can be bound for reading, writing, or both.
GlKind
Indicator of whether we are using the embedded version of OpenGL.