Module brush

Module brush 

Brush defines a way to fill an arbitrary surface. See Brush docs for more info and usage examples.

Structs

GradientPoint
Gradient point defines a point on a surface with a color.

Enums

Brush
Brush defines a way to fill an arbitrary surface.