Module check_box

Module check_box 

Checkbox is a UI widget that have three states - Checked, Unchecked and Undefined. In most cases, it is used only with two values which fit in bool type. Third, undefined, state is used for specific situations when your data have such state. See CheckBox docs for more info and usage examples.

Structs

CheckBox
Checkbox is a UI widget that have three states - Checked, Unchecked and Undefined. In most cases, it is used only with two values which fit in bool type. Third, undefined, state is used for specific situations when your data have such state.
CheckBoxBuilder
Check box builder creates CheckBox instances and adds them to the user interface.

Enums

CheckBoxMessage
A set of possible check box messages.