Module dock

Module dock 

The docking manager allows you to dock windows and hold them in-place.

Notes

Docking manager can hold any types of UI elements, but dragging works only for windows.

Modules

config

Structs

DockingManager
Docking manager is a special container widget, that holds a bunch of children widgets in-place using Tiles and a bunch of floating windows. Any window can be undocked and become a floating window and vice versa. Docking manager is typically used to “pack” multiple windows into a rectangular. The most notable use case is IDEs where you can drag, dock, undock, stack windows.
DockingManagerBuilder
Tile
TileBuilder

Enums

DockingManagerMessage
Supported docking manager-specific messages.
SplitDirection
TileContent
TileMessage

Constants

DEFAULT_ANCHOR_COLOR
DEFAULT_SPLITTER_SIZE

Functions

make_default_anchor