Module dropdown_list

Module dropdown_list 

Drop-down list. This is control which shows the currently selected item and provides a drop-down list to select its current item. It is build using composition with standard list view. See DropdownList docs for more info and usage examples.

Structs

DropdownList
Drop-down list is a control which shows the currently selected item and provides a drop-down list to select its current item. It is used to show a single selected item in a compact way.
DropdownListBuilder
Dropdown list builder allows to create DropdownList widgets and add them a user interface.

Enums

DropdownListMessage
A set of possible messages for DropdownList widget.