pub struct FontBuilder { /* private fields */ }Expand description
Font builder allows you to load fonts in a declarative manner.
Implementations
Sourceimpl FontBuilder
impl FontBuilder
Sourcepub fn new() -> FontBuilder
pub fn new() -> FontBuilder
Creates a default FontBuilder.
Sourcepub fn with_page_size(self, size: usize) -> FontBuilder
pub fn with_page_size(self, size: usize) -> FontBuilder
The size of each atlas page in font pixels. Each page is a square measuring page_size x page_size.
Sourcepub fn with_bold(self, font: Resource<Font>) -> FontBuilder
pub fn with_bold(self, font: Resource<Font>) -> FontBuilder
The bold version of this font.
Sourcepub fn with_italic(self, font: Resource<Font>) -> FontBuilder
pub fn with_italic(self, font: Resource<Font>) -> FontBuilder
The italic version of this font.
pub fn with_bold_italic(self, font: Resource<Font>) -> FontBuilder
Sourcepub fn with_fallback(self, font: Resource<Font>) -> FontBuilder
pub fn with_fallback(self, font: Resource<Font>) -> FontBuilder
A fallback font to supply glyphs for special characters that are not represented in this font.
Sourcepub fn with_fallbacks(
self,
fallbacks: Vec<Option<Resource<Font>>>,
) -> FontBuilder
pub fn with_fallbacks( self, fallbacks: Vec<Option<Resource<Font>>>, ) -> FontBuilder
A list of fallback fonts to supply glyphs for special characters that are not represented in this font, replacing any existing fallbacks for this font.
Sourcepub async fn build_from_file(
self,
path: impl AsRef<Path>,
io: &(dyn ResourceIo + 'static),
resource_manager: &ResourceManager,
) -> Result<Font, LoadError>
pub async fn build_from_file( self, path: impl AsRef<Path>, io: &(dyn ResourceIo + 'static), resource_manager: &ResourceManager, ) -> Result<Font, LoadError>
Creates a new font from the data at the specified path.
Sourcepub fn build_from_memory(
self,
data: impl Deref<Target = [u8]>,
resource_manager: &ResourceManager,
) -> Result<Font, &'static str>
pub fn build_from_memory( self, data: impl Deref<Target = [u8]>, resource_manager: &ResourceManager, ) -> Result<Font, &'static str>
Creates a new font from bytes in memory.