FontGlyph

Struct FontGlyph 

pub struct FontGlyph {
    pub bitmap_top: f32,
    pub bitmap_left: f32,
    pub bitmap_width: f32,
    pub bitmap_height: f32,
    pub advance: f32,
    pub tex_coords: [Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>; 4],
    pub page_index: usize,
    pub bounds: Rect<f32>,
}
The geometric data specifying where to find a glyph on a font atlas texture for rendering text.

Fields

bitmap_top: f32

The vertical position of the glyph relative to other glyphs on the line, measured in font pixels. This would be 0 for a glyph with its bottom directly on the baseline, but may be negative if the glyph extends below the baseline.

bitmap_left: f32

The horizontal position of the glyph relative to other glyphs on the line, measured in font pixels. This would usually be 0, but a negative value would allow a glyph to extend into the space usually reserved for the previous glyph on the line.

bitmap_width: f32

The width of the glyph as measured in pixels. This may be more or less than advance depending on how much this glyph crowds into the space of the glyphs to the left and right of it on the line.

bitmap_height: f32

The height of the glyph as measured in pixels.

advance: f32

The horizontal distance between the start of this glyph and the start of the next glyph, measured in pixels.

tex_coords: [Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>; 4]

The position of the texture data of this glyph on the atlas page. Each corner of the quad containing the glyph is given a UV coordinate.

page_index: usize

The index of the atlas page.

bounds: Rect<f32>

The position of the glyph measured to sub-pixel precision. It is like bitmap_top, bitmap_left, bitmap_width, and bitmap_height, except that those measure the whole pixels that the font needs for rendering while this rect contains the exact outline of the glyph, which is potentially smaller.