Module formatted_text

Module formatted_text 

Structs

FormattedText
FormattedTextBuilder
GlyphDrawValues
Position
Defines a position in the text. It is just a coordinates of a character in text.
Run
The style of a portion of text within a range.
RunSet
TextGlyph
TextLine

Enums

DrawValueLayer
WrapMode
Wrapping mode for formatted text.

Type Aliases

RunBuilderDeprecated