Image widget is a rectangle with a texture, it is used draw custom bitmaps. See Image docs for more info
and usage examples.
Structs
- Image
- Image widget is a rectangle with a texture, it is used draw custom bitmaps. The UI in the engine is vector-based, Image widget is the only way to draw a bitmap. Usage of the Image is very simple:
- Image
Builder - Image builder is used to create
Imagewidget instances and register them in the user interface.
Enums
- Image
Message - A set of messages that could be used to alter
Imagewidget state at runtime.