pub struct PropertyEditorBuildContext<'a, 'b, 'c, 'd> {
pub build_context: &'a mut BuildContext<'c>,
pub property_info: &'b FieldRef<'b, 'd>,
pub environment: Option<Arc<dyn InspectorEnvironment>>,
pub definition_container: Arc<PropertyEditorDefinitionContainer>,
pub layer_index: usize,
pub generate_property_string_values: bool,
pub filter: PropertyFilter,
pub name_column_width: f32,
pub base_path: String,
pub has_parent_object: bool,
}Expand description
This structure is passed to PropertyEditorDefinition::create_instance in order to allow it to build a widget to allow a property to be edited.
Fields
build_context: &'a mut BuildContext<'c>General context for widget building to be used for creating the editor.
property_info: &'b FieldRef<'b, 'd>The FieldInfo of the property to edit, extracted from the object we are inspecting by reflection.
environment: Option<Arc<dyn InspectorEnvironment>>Untyped reference to the environment that the Inspector is being used in. This will often be fyroxed_base::inspector::EditorEnvironment when the Inspector is being used in Fyroxed, but Inspector widgets can be used in other applications, and we can access those applications by casting the environment to the appropriate type.
definition_container: Arc<PropertyEditorDefinitionContainer>The list of the Inspectors property editors. This allows one property editor to make use of other property editors.
layer_index: usizeEditors can be nested within other editors, such as when an array editor contains editors for each element of the array. The layer_index indicates how deeply nested the editor widget we are creating will be.
generate_property_string_values: boolWhen true, this indicates that an Inspector should generate strings from format!("{:?}", field), for each field.
Having this in the property editor build context indicates how any Inspectors that are created as part of the new
editor should behave.
filter: PropertyFilterDetermines how properties should be filtered in any Inspectors created within the editor that is being built.
name_column_width: f32Width of the property name column.
base_path: Stringhas_parent_object: boolA flag, that defines whether the inspectable object has a parent object from which it can
obtain initial property values when clicking on the “Revert” button. This flag is used only for
crate::core::variable::InheritableVariable properties, primarily to hide “Revert” button
when it does nothing (when there’s no parent object).