InspectorContextArgs

Struct InspectorContextArgs 

pub struct InspectorContextArgs<'a, 'b, 'c> {
    pub object: &'a (dyn Reflect + 'static),
    pub ctx: &'b mut BuildContext<'c>,
    pub definition_container: Arc<PropertyEditorDefinitionContainer>,
    pub environment: Option<Arc<dyn InspectorEnvironment>>,
    pub layer_index: usize,
    pub generate_property_string_values: bool,
    pub filter: PropertyFilter,
    pub name_column_width: f32,
    pub base_path: String,
    pub has_parent_object: bool,
}

Fields

object: &'a (dyn Reflect + 'static)ctx: &'b mut BuildContext<'c>definition_container: Arc<PropertyEditorDefinitionContainer>environment: Option<Arc<dyn InspectorEnvironment>>layer_index: usizegenerate_property_string_values: boolfilter: PropertyFiltername_column_width: f32base_path: Stringhas_parent_object: bool

A flag, that defines whether the inspectable object has a parent object from which it can obtain initial property values when clicking on “Revert” button. This flag is used only for crate::core::variable::InheritableVariable properties, primarily to hide “Revert” button when it does nothing (when there’s no parent object).