Module key

Module key 

A set of editors for hot keys and key bindings. See HotKeyEditor and KeyBindingEditor widget’s docs for more info and usage examples.

Structs

HotKeyEditor
Hot key editor is used to provide a unified way of editing an arbitrary combination of modifiers keyboard keys (such as Ctrl, Shift, Alt) with any other key. It could be used, if you need a simple way to add an editor for HotKey.
HotKeyEditorBuilder
Hot key editor builder creates HotKeyEditor widget instances and adds them to the user interface.
KeyBindingEditor
Key binding editor is used to provide a unified way of setting a key binding.
KeyBindingEditorBuilder
Key binding editor builder is used to create KeyBindingEditor widgets and add them to the user interface.

Enums

HotKey
Hot key is a combination of a key code with an arbitrary set of keyboard modifiers (such as Ctrl, Shift, Alt keys).
HotKeyEditorMessage
A set of messages, that is used to alternate the state of HotKeyEditor widget or to listen to its changes.
KeyBinding
Key binding is a simplified version of HotKey that consists of a single physical key code. It is usually used for “unconditional” (independent of modifier keys state) triggering of some action.
KeyBindingEditorMessage
A set of messages, that is used to modify KeyBindingEditor state or to listen to its changes.