Module list_view

Module list_view 

List view is used to display lists with arbitrary items. It supports single-selection, and by default, it stacks the items vertically.

Structs

ListView
List view is used to display lists with arbitrary items. It supports multiple selection and by default, it stacks the items vertically (this can be changed by providing a custom panel for the items, see the section below).
ListViewBuilder
List view builder is used to create ListView widget instances and add them to a user interface.
ListViewItem
A wrapper for list view items, that is used to add selection functionality to arbitrary items.

Enums

ListViewMessage
A set of messages that can be used to modify/fetch the state of a ListView widget at runtime.