Module popup

Module popup 

Popup is used to display other widgets in floating panel, that could lock input in its bounds. See Popup docs for more info and usage examples.

Structs

Popup
Popup is used to display other widgets in floating panel, that could lock input in its bounds.
PopupBuilder
Popup widget builder is used to create Popup widget instances and add them to the user interface.

Enums

Placement
Defines a method of popup placement.
PopupMessage
A set of messages for Popup widget.