pub struct PopupBuilder { /* private fields */ }Expand description
Popup widget builder is used to create Popup widget instances and add them to the user interface.
Implementations
Sourceimpl PopupBuilder
impl PopupBuilder
Sourcepub fn new(widget_builder: WidgetBuilder) -> PopupBuilder
pub fn new(widget_builder: WidgetBuilder) -> PopupBuilder
Creates new builder instance.
Sourcepub fn with_placement(self, placement: Placement) -> PopupBuilder
pub fn with_placement(self, placement: Placement) -> PopupBuilder
Sets the desired popup placement.
Sourcepub fn with_smart_placement(self, smart_placement: bool) -> PopupBuilder
pub fn with_smart_placement(self, smart_placement: bool) -> PopupBuilder
Enables or disables smart placement.
Sourcepub fn stays_open(self, value: bool) -> PopupBuilder
pub fn stays_open(self, value: bool) -> PopupBuilder
Defines whether to keep the popup open when a user clicks outside its content or not.
Sourcepub fn with_content(
self,
content: Handle<impl ObjectOrVariant<UiNode>>,
) -> PopupBuilder
pub fn with_content( self, content: Handle<impl ObjectOrVariant<UiNode>>, ) -> PopupBuilder
Sets the content of the popup.
Sourcepub fn with_owner(self, owner: Handle<UiNode>) -> PopupBuilder
pub fn with_owner(self, owner: Handle<UiNode>) -> PopupBuilder
Sets the desired owner of the popup, to which the popup will relay its own messages.
Sourcepub fn with_restrict_picking(self, restrict: bool) -> PopupBuilder
pub fn with_restrict_picking(self, restrict: bool) -> PopupBuilder
Sets a flag, that defines whether the popup should restrict all the mouse input or not.
Sourcepub fn build_popup(self, ctx: &mut BuildContext<'_>) -> Popup
pub fn build_popup(self, ctx: &mut BuildContext<'_>) -> Popup
Builds the popup widget, but does not add it to the user interface. Could be useful if you’re making your own derived version of the popup.