Module scroll_bar

Module scroll_bar 

Scroll bar is used to represent a value on a finite range. It has a thumb that shows the current value of the bar. See ScrollBar docs for more info and usage examples.

Structs

ScrollBar
Scroll bar is used to represent a value on a finite range. It has a thumb that shows the current value on the bar. Usually it is used in pair with crate::scroll_panel::ScrollPanel to create something like crate::scroll_viewer::ScrollViewer widget. However, it could also be used to create sliders to show some value that lies within some range.
ScrollBarBuilder
Scroll bar widget is used to create ScrollBar widget instances and add them to the user interface.

Enums

ScrollBarMessage
A set of messages that can be accepted by ScrollBar widget.