Module scroll_viewer

Module scroll_viewer 

Scroll viewer is a scrollable region with two scroll bars for each axis. It is used to wrap a content of unknown size to ensure that all of it will be accessible in a parent widget bounds. See ScrollViewer docs for more info and usage examples.

Structs

ScrollViewer
Scroll viewer is a scrollable region with two scroll bars for each axis. It is used to wrap a content of unknown size to ensure that all of it will be accessible in a parent widget bounds. For example, it could be used in a Window widget to allow the content of the window to be accessible, even if the window is smaller than the content.
ScrollViewerBuilder
Scroll viewer builder creates ScrollViewer widget instances and adds them to the user interface.

Enums

ScrollViewerMessage
A set of messages that could be used to alternate the state of a ScrollViewer widget.