Module thumb

Module thumb 

Structs

Thumb
A helper widget that is used to provide basic dragging interaction. The widget itself does not move when being dragged, instead it captures mouse input when clicked and calculates the difference between its current position and its initial position. The user is responsible for the actual movement of the thumb widget.
ThumbBuilder

Enums

ThumbMessage