Module uuid

Module uuid 

UUID editor is used to show an arbitrary UUID and give an ability to generate a new value. See UuidEditor docs for more info and usage examples.

Structs

UuidEditor
UUID editor is used to show an arbitrary UUID and give an ability to generate a new value. It is widely used in crate::inspector::Inspector to show and edit UUIDs.
UuidEditorBuilder
Creates UuidEditor widgets and add them to the user interface.

Enums

UuidEditorMessage
A set of messages that is used to fetch or modify values of UuidEditor widgets.