SceneLoaderOutput

Type Alias SceneLoaderOutput 

pub type SceneLoaderOutput = LoaderOutput<Scene>;
Alias for LoaderOutput<Scene>;

Aliased Type

pub struct SceneLoaderOutput {
    pub payload: Scene,
    pub path: PathBuf,
    pub data: Vec<u8>,
}

Fields

payload: Scene

The object produced by the loader.

path: PathBuf

A path of the source file.

data: Vec<u8>

A raw data from which the loader output was created from. Usually it is just a content of the source file.