Module uniform

Module uniform 

Uniform buffer cache could be considered as pool of uniform buffers of fixed size. See UniformBufferCache for more info.

Structs

UniformBlockLocation
The position of a uniform within a UniformMemoryAllocator.
UniformBufferCache
Uniform buffer cache could be considered as pool of uniform buffers of fixed size, that can be used to fetch free buffer for drawing. Uniform buffers usually have quite limited size (guaranteed to be at least 16kb and on vast majority of GPUs the upper limit is 65kb) and they are intended to be used as a storage for relatively small set of data that can fit into L1 cache of a GPU for very fast access.
UniformMemoryAllocator