Module observer

Module observer 

An observer holds all the information required to render a scene from a particular point of view. Contains all information for rendering, effectively decouples rendering entities from scene entities. See Observer docs for more info.

Structs

Observer
An observer holds all the information required to render a scene from a particular point of view. Contains all information for rendering, effectively decouples rendering entities from scene entities. Observer can be constructed from an arbitrary set of data or from scene entities, such as cameras, reflection probes.
ObserverPosition
Observer position contains all the data, that describes an observer position in 3D space. It could be a real camera, light source’s “virtual camera” that is used for shadow mapping, etc.
ObserversCollection
Collections of observers in a scene.
ReflectionProbeData
The data used by the renderer when it’s rendering a reflection probe.