Module ui_renderer

Module ui_renderer 

See UiRenderer docs.

Structs

UiRenderContext
A set of parameters to render a specified user interface drawing context.
UiRenderInfo
Contains all the info required to render a user interface.
UiRenderer
User interface renderer allows you to render drawing context in specified render target.