pub enum Scheme {
File,
Data,
None,
Other,
}Expand description
One of the scheme types that the parser can recognize.
Variants
File
A file URI indicates that this is an absolute path to a file. This method of identifying files is not supported.
Data
A data URI contains image or model data encoded in base64.
None
There was no ‘:’ to identify a scheme name, which means that this URI will be interpreted as a relative file path and the file system will be searched for the named asset.
Other
A scheme name was specified using a ‘:’, but it was not among these expected schemes.