pub struct GltfLoader {
pub resource_manager: ResourceManager,
pub default_import_options: ModelImportOptions,
}Expand description
This object performs the loading of files in glTF format with extension “gltf” or “glb”.
Fields
resource_manager: ResourceManagerResourceManager is needed so that textures and mesh data can be loaded from additional resources. The glTF format allows for other assets to be referenced by file path.
default_import_options: ModelImportOptionsImport options control where this loader should search for additional resources.