Module model

Module model 

Contains all data structures and method to work with model resources.

Model is an isolated scene that is used to create copies of its data - this process is known as instantiation. Isolation in this context means that such scene cannot be modified, rendered, etc. It just a data source.

All instances will have references to resource they were created from - this will help to get correct vertex and indices buffers when loading a save file, loader will just take all needed data from resource so we don’t need to store such data in save file. Also this mechanism works perfectly when you changing resource in external editor (3Ds max, Maya, Blender, etc.) engine will assign correct visual data when loading a saved game.

Supported formats

Currently only FBX (common format in game industry for storing complex 3d models) and RGS (native Fyroxed format) formats are supported.

Modules

loader
Model loader.

Structs

InstantiationContext
Instantiation context holds additional data that could be useful for a prefab instantiation.
Model
See module docs.
ModelImportOptions
A set of options that will be applied to a model resource when loading it from external source.

Enums

MaterialSearchOptions
Defines a way of searching materials when loading a model resource from foreign file format such as FBX.
ModelLoadError
All possible errors that may occur while trying to load model from some data source.

Traits

AnimationSource
Common trait that has animation retargetting methods.
ModelResourceExtension
Extension trait for model resources.

Type Aliases

ModelResource
Type alias for model resources.