Module texture

Module texture 

Everything related to textures. See fyrox_texture crate docs for more info.

Modules

loader
Texture loader.

Structs

PLACEHOLDER
Placeholder texture.
Texture
Actual texture data.
TextureBytes
Data storage of a texture.
TextureDataRefMut
A special reference holder that provides mutable access to content of the texture and automatically calculates hash of the data in its destructor.
TextureImportOptions
Allows you to define a set of parameters for a texture resource.

Enums

CompressionOptions
Texture compression options.
MipFilter
A filter for mip-map generation.
TextureError
An error that may occur during texture operations.
TextureKind
Texture kind.
TextureMagnificationFilter
The texture magnification function is used when the pixel being textured maps to an area less than or equal to one texture element.
TextureMinificationFilter
The texture minifying function is used whenever the pixel being textured maps to an area greater than one texture element.
TexturePixelKind
Texture kind defines pixel format of texture.
TextureWrapMode
Defines a law of texture coordinate modification.

Traits

TextureResourceExtension
Extension trait for texture resources.

Type Aliases

TextureResource
Type alias for texture resources.