pub struct TextureImportOptions { /* private fields */ }Expand description
Allows you to define a set of parameters for a texture resource.
Details
Usually the content of this structure is stored in a separate file with .options extension. Typical content of a settings file should look like this:
(
minification_filter: Linear,
magnification_filter: Linear,
s_wrap_mode: Repeat,
t_wrap_mode: ClampToEdge,
anisotropy: 8.0,
compression: NoCompression,
)Implementations
Sourceimpl TextureImportOptions
impl TextureImportOptions
pub const MINIFICATION_FILTER: &'static str = "minification_filter"
pub const MAGNIFICATION_FILTER: &'static str = "magnification_filter"
pub const S_WRAP_MODE: &'static str = "s_wrap_mode"
pub const T_WRAP_MODE: &'static str = "t_wrap_mode"
pub const R_WRAP_MODE: &'static str = "r_wrap_mode"
pub const ANISOTROPY: &'static str = "anisotropy"
pub const COMPRESSION: &'static str = "compression"
pub const MIP_FILTER: &'static str = "mip_filter"
pub const FLIP_GREEN_CHANNEL: &'static str = "flip_green_channel"
pub const BASE_LEVEL: &'static str = "base_level"
pub const MAX_LEVEL: &'static str = "max_level"
pub const MIN_LOD: &'static str = "min_lod"
pub const MAX_LOD: &'static str = "max_lod"
pub const LOD_BIAS: &'static str = "lod_bias"
Sourceimpl TextureImportOptions
impl TextureImportOptions
Sourcepub fn with_minification_filter(
self,
minification_filter: TextureMinificationFilter,
) -> TextureImportOptions
pub fn with_minification_filter( self, minification_filter: TextureMinificationFilter, ) -> TextureImportOptions
Sets new minification filter which will be applied to every imported texture as default value.
Sourcepub fn set_minification_filter(
&mut self,
minification_filter: TextureMinificationFilter,
)
pub fn set_minification_filter( &mut self, minification_filter: TextureMinificationFilter, )
Sets new minification filter which will be applied to every imported texture as default value.
Sourcepub fn with_magnification_filter(
self,
magnification_filter: TextureMagnificationFilter,
) -> TextureImportOptions
pub fn with_magnification_filter( self, magnification_filter: TextureMagnificationFilter, ) -> TextureImportOptions
Sets new magnification filter which will be applied to every imported texture as default value.
Sourcepub fn set_magnification_filter(
&mut self,
magnification_filter: TextureMagnificationFilter,
)
pub fn set_magnification_filter( &mut self, magnification_filter: TextureMagnificationFilter, )
Sets new magnification filter which will be applied to every imported texture as default value.
Sourcepub fn with_s_wrap_mode(
self,
s_wrap_mode: TextureWrapMode,
) -> TextureImportOptions
pub fn with_s_wrap_mode( self, s_wrap_mode: TextureWrapMode, ) -> TextureImportOptions
Sets new S coordinate wrap mode which will be applied to every imported texture as default value.
Sourcepub fn set_s_wrap_mode(&mut self, s_wrap_mode: TextureWrapMode)
pub fn set_s_wrap_mode(&mut self, s_wrap_mode: TextureWrapMode)
Sets new S coordinate wrap mode which will be applied to every imported texture as default value.
Sourcepub fn with_t_wrap_mode(
self,
t_wrap_mode: TextureWrapMode,
) -> TextureImportOptions
pub fn with_t_wrap_mode( self, t_wrap_mode: TextureWrapMode, ) -> TextureImportOptions
Sets new T coordinate wrap mode which will be applied to every imported texture as default value.
Sourcepub fn set_t_wrap_mode(&mut self, t_wrap_mode: TextureWrapMode)
pub fn set_t_wrap_mode(&mut self, t_wrap_mode: TextureWrapMode)
Sets new T coordinate wrap mode which will be applied to every imported texture as default value.
Sourcepub fn with_anisotropy(self, anisotropy: f32) -> TextureImportOptions
pub fn with_anisotropy(self, anisotropy: f32) -> TextureImportOptions
Sets new anisotropy level which will be applied to every imported texture as default value.
Sourcepub fn set_anisotropy(&mut self, anisotropy: f32)
pub fn set_anisotropy(&mut self, anisotropy: f32)
Sets new anisotropy level which will be applied to every imported texture as default value.
Sourcepub fn with_compression(
self,
compression: CompressionOptions,
) -> TextureImportOptions
pub fn with_compression( self, compression: CompressionOptions, ) -> TextureImportOptions
Sets desired texture compression.
Sourcepub fn set_compression(&mut self, compression: CompressionOptions)
pub fn set_compression(&mut self, compression: CompressionOptions)
Sets desired texture compression.
Sourcepub fn with_base_level(self, base_level: usize) -> TextureImportOptions
pub fn with_base_level(self, base_level: usize) -> TextureImportOptions
Same effect as Texture::set_base_level.
Sourcepub fn set_base_level(&mut self, base_level: usize)
pub fn set_base_level(&mut self, base_level: usize)
Same effect as Texture::set_base_level.
Sourcepub fn with_max_level(self, max_level: usize) -> TextureImportOptions
pub fn with_max_level(self, max_level: usize) -> TextureImportOptions
Same effect as Texture::set_max_level.
Sourcepub fn set_max_level(&mut self, max_level: usize)
pub fn set_max_level(&mut self, max_level: usize)
Same effect as Texture::set_max_level.
Sourcepub fn with_min_lod(self, min_lod: f32) -> TextureImportOptions
pub fn with_min_lod(self, min_lod: f32) -> TextureImportOptions
Same effect as Texture::set_min_lod.
Sourcepub fn set_min_lod(&mut self, min_lod: f32)
pub fn set_min_lod(&mut self, min_lod: f32)
Same effect as Texture::set_min_lod.
Sourcepub fn with_max_lod(self, max_lod: f32) -> TextureImportOptions
pub fn with_max_lod(self, max_lod: f32) -> TextureImportOptions
Same effect as Texture::set_max_lod.
Sourcepub fn set_max_lod(&mut self, max_lod: f32)
pub fn set_max_lod(&mut self, max_lod: f32)
Same effect as Texture::set_max_lod.
Sourcepub fn with_lod_bias(self, lod_bias: f32) -> TextureImportOptions
pub fn with_lod_bias(self, lod_bias: f32) -> TextureImportOptions
Same effect as Texture::set_lod_bias.
Sourcepub fn set_lod_bias(&mut self, lod_bias: f32)
pub fn set_lod_bias(&mut self, lod_bias: f32)
Same effect as Texture::set_lod_bias.