AnimationContainerExt

Trait AnimationContainerExt 

pub trait AnimationContainerExt {
    // Required method
    fn update_animations(&mut self, nodes: &mut NodePool, dt: f32);
}
Extension trait for AnimationContainer.

Required Methods

fn update_animations(&mut self, nodes: &mut NodePool, dt: f32)

Updates all animations in the container and applies their poses to respective nodes. This method is intended to be used only by the internals of the engine!

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors