Module base

Module base 

Contains all structures and methods to create and manage base scene graph nodes.

For more info see Base

Structs

Base
Base scene graph node is a simplest possible node, it is used to build more complex ones using composition. It contains all fundamental properties for each scene graph nodes, like local and global transforms, name, lifetime, etc. Base node is a building block for all complex node hierarchies - it contains list of children and handle to parent node.
BaseBuilder
Base node builder allows you to create nodes in declarative manner.
LevelOfDetail
Level of detail is a collection of objects for given normalized distance range. Objects will be rendered only if they’re in specified range. Normalized distance is a distance in (0; 1) range where 0 - closest to camera, 1 - farthest. Real distance can be obtained by multiplying normalized distance with z_far of current projection matrix.
LodGroup
LOD (Level-Of-Detail) group is a set of cascades (levels), where each cascade takes specific distance range. Each cascade contains list of objects that should or shouldn’t be rendered if distance satisfy cascade range. LOD may significantly improve performance if your scene contains lots of high poly objects and objects may be far away from camera. Distant objects in this case will be rendered with lower details freeing precious GPU resources for other useful tasks.
Property
A custom property.
SceneNodeId
Unique id of a node, that could be used as a reliable “index” of the node. This id is mostly useful for network games.
ScriptRecord
A script container record.

Enums

Mobility
Mobility defines a group for scene node which has direct impact on performance and capabilities of nodes.
NodeScriptMessage
A script message from scene node. It is used for deferred initialization/deinitialization.
PropertyValue
A property value.