Module collider

Module collider 

Collider is a geometric entity that can be attached to a rigid body to allow participate it participate in contact generation, collision response and proximity queries.

Structs

BallShape
Ball is an idea sphere shape defined by a single parameters - its radius.
BitMask
A set of bits used for pairwise collision filtering.
CapsuleShape
Arbitrary capsule shape defined by 2 points (which forms axis) and a radius.
Collider
Collider is a geometric entity that can be attached to a rigid body to allow participate it participate in contact generation, collision response and proximity queries.
ColliderBuilder
Collider builder allows you to build a collider node in declarative mannner.
ConeShape
Cone shape aligned in Y axis.
ConvexPolyhedronShape
Arbitrary convex polyhedron shape.
CuboidShape
Cuboid shape (box).
CylinderShape
Cylinder shape aligned in Y axis.
GeometrySource
Geometry source for colliders with complex geometry.
HeightfieldShape
Arbitrary height field shape.
InteractionGroups
Pairwise filtering using bit masks.
QueryFilterFlags
Flags for excluding whole sets of colliders from a scene query.
SegmentShape
Arbitrary segment shape defined by two points.
TriangleShape
Arbitrary triangle shape.
TrimeshShape
Arbitrary triangle mesh shape.

Enums

ColliderShape
Possible collider shapes.
TOIStatus
The status of the time-of-impact computation algorithm.