Module dim2

Module dim2 

The module contains 2D scene nodes and physics. Despite the naming, scene nodes are still 3D but physics simulation is in true 2D.

Modules

collider
Collider is a geometric entity that can be attached to a rigid body to allow to participate it participate in contact generation, collision response and proximity queries.
joint
Joint is used to restrict motion of two rigid bodies.
physics
Scene physics module.
rectangle
Rectangle is the simplest “2D” node, it can be used to create “2D” graphics. 2D is in quotes here because the node is actually a 3D node, like everything else in the engine.
rigidbody
Rigid body is a physics entity that responsible for the dynamics and kinematics of the solid.