pub struct ColliderBuilder { /* private fields */ }Expand description
Collider builder allows you to build a collider node in declarative manner.
Implementations
Sourceimpl ColliderBuilder
impl ColliderBuilder
Sourcepub fn new(base_builder: BaseBuilder) -> Self
pub fn new(base_builder: BaseBuilder) -> Self
Creates new collider builder.
Sourcepub fn with_shape(self, shape: ColliderShape) -> Self
pub fn with_shape(self, shape: ColliderShape) -> Self
Sets desired shape of the collider.
Sourcepub fn with_density(self, density: Option<f32>) -> Self
pub fn with_density(self, density: Option<f32>) -> Self
Sets desired density value.
Sourcepub fn with_restitution(self, restitution: f32) -> Self
pub fn with_restitution(self, restitution: f32) -> Self
Sets desired restitution value.
Sourcepub fn with_friction(self, friction: f32) -> Self
pub fn with_friction(self, friction: f32) -> Self
Sets desired friction value.
Sourcepub fn with_sensor(self, sensor: bool) -> Self
pub fn with_sensor(self, sensor: bool) -> Self
Sets whether this collider will be used a sensor or not.
Sourcepub fn with_solver_groups(self, solver_groups: InteractionGroups) -> Self
pub fn with_solver_groups(self, solver_groups: InteractionGroups) -> Self
Sets desired solver groups.
Sourcepub fn with_collision_groups(self, collision_groups: InteractionGroups) -> Self
pub fn with_collision_groups(self, collision_groups: InteractionGroups) -> Self
Sets desired collision groups.
Sourcepub fn with_friction_combine_rule(self, rule: CoefficientCombineRule) -> Self
pub fn with_friction_combine_rule(self, rule: CoefficientCombineRule) -> Self
Sets desired friction combine rule.
Sourcepub fn with_restitution_combine_rule(self, rule: CoefficientCombineRule) -> Self
pub fn with_restitution_combine_rule(self, rule: CoefficientCombineRule) -> Self
Sets desired restitution combine rule.
Sourcepub fn build_collider(self) -> Collider
pub fn build_collider(self) -> Collider
Creates collider node, but does not add it to a graph.
Sourcepub fn build_node(self) -> Node
pub fn build_node(self) -> Node
Creates collider node, but does not add it to a graph.