Module physics

Module physics 

Scene physics module.

Structs

ContactData
Data of the contact.
ContactManifold
A contact manifold between two colliders.
ContactPair
Contact info for pair of colliders.
Intersection
A ray intersection result.
IntersectionPair
Intersection info for pair of colliders.
PhysicsWorld
Physics world is responsible for physics simulation in the engine. There is a very few public methods, mostly for ray casting. You should add physical entities using scene graph nodes, such as RigidBody, Collider, Joint.
QueryFilter
A filter tha describes what collider should be included or excluded from a scene query.
RayCastOptions
A set of options for the ray cast.
TOI
The result of a time-of-impact (TOI) computation.

Enums

ShapeType
Enum representing the type of a shape.
TypedShape
Enum representing the shape with its actual type

Traits

QueryResultsStorage
A trait for ray cast results storage. It has two implementations: Vec and ArrayVec. Latter is needed for the cases where you need to avoid runtime memory allocations and do everything on stack.
Shape
Trait implemented by shapes usable by Rapier.