pub struct ContactPair {
pub collider1: Handle<Collider>,
pub collider2: Handle<Collider>,
pub manifolds: Vec<ContactManifold>,
pub has_any_active_contact: bool,
}Expand description
Contact info for pair of colliders.
Fields
collider1: Handle<Collider>The first collider involved in the contact pair.
collider2: Handle<Collider>The second collider involved in the contact pair.
manifolds: Vec<ContactManifold>The set of contact manifolds between the two colliders. All contact manifold contain themselves contact points between the colliders.
has_any_active_contact: boolIs there any active contact in this contact pair?
Implementations
Sourceimpl ContactPair
impl ContactPair
Sourcepub fn other(&self, subject: Handle<Collider>) -> Handle<Collider>
pub fn other(&self, subject: Handle<Collider>) -> Handle<Collider>
Given the handle of a collider that is expected to be part of the collision, return the other node involved in the collision. Often one will have a list of contact pairs for some collider, but that collider may be the first member of some pairs and the second member of other pairs. This method simplifies determining which objects a collider has collided with.