Module joint

Module joint 

Joint is used to restrict motion of two rigid bodies.

Structs

BallJoint
Ball joint locks any translational moves between two objects on the axis between objects, but allows rigid bodies to perform relative rotations. The real world example is a human shoulder, pendulum, etc.
FixedJoint
A fixed joint ensures that two rigid bodies does not move relative to each other. There is no straightforward real-world example, but it can be thought as two bodies were “welded” together.
Joint
Joint is used to restrict motion of two rigid bodies. There are numerous examples of joints in real life: door hinge, ball joints in human arms, etc.
JointBuilder
Joint builder allows you to build Joint node in a declarative manner.
PrismaticJoint
Prismatic joint prevents any relative movement between two rigid-bodies, except for relative translations along one axis. The real world example is a sliders that used to support drawers.
RevoluteJoint
Revolute joint prevents any relative movement between two rigid bodies, except relative rotation along one axis. The real world example is wheels, fans, etc. It can also be used to simulate door hinge.

Enums

JointParams
The exact kind of the joint.