pub struct JointBuilder { /* private fields */ }Expand description
Joint builder allows you to build Joint node in a declarative manner.
Implementations
Sourceimpl JointBuilder
impl JointBuilder
Sourcepub fn new(base_builder: BaseBuilder) -> Self
pub fn new(base_builder: BaseBuilder) -> Self
Creates a new joint builder instance.
Sourcepub fn with_params(self, params: JointParams) -> Self
pub fn with_params(self, params: JointParams) -> Self
Sets desired joint parameters which defines exact type of the joint.
Sourcepub fn with_motor_params(self, motor_params: JointMotorParams) -> Self
pub fn with_motor_params(self, motor_params: JointMotorParams) -> Self
Set desired motor parameters which defines how the joint motor will behave.
Sourcepub fn with_body1(self, body1: Handle<RigidBody>) -> Self
pub fn with_body1(self, body1: Handle<RigidBody>) -> Self
Sets desired first body of the joint. This handle should be a handle to rigid body node, otherwise joint will have no effect!
Sourcepub fn with_body2(self, body2: Handle<RigidBody>) -> Self
pub fn with_body2(self, body2: Handle<RigidBody>) -> Self
Sets desired second body of the joint. This handle should be a handle to rigid body node, otherwise joint will have no effect!
Sourcepub fn with_contacts_enabled(self, enabled: bool) -> Self
pub fn with_contacts_enabled(self, enabled: bool) -> Self
Sets whether the connected bodies should ignore collisions with each other or not.
Sourcepub fn with_auto_rebinding_enabled(self, auto_rebind: bool) -> Self
pub fn with_auto_rebinding_enabled(self, auto_rebind: bool) -> Self
Sets whether the joint should automatically rebind two rigid bodies if the joint has changed its global position.
Sourcepub fn build_joint(self) -> Joint
pub fn build_joint(self) -> Joint
Creates new Joint node, but does not add it to the graph.
Sourcepub fn build_node(self) -> Node
pub fn build_node(self) -> Node
Creates new Joint node, but does not add it to the graph.