pub enum FrustumSplitOptions {
Absolute {
far_planes: [f32; 3],
},
Relative {
fractions: [f32; 3],
},
}Expand description
Frustum split options defines how to split camera’s frustum to generate cascades.
Variants
Absolute
Camera frustum will be split into a CSM_NUM_CASCADES splits where each sub-frustum
will have fixed far plane location.
This option allows you to set far planes very precisely, thus allowing you to set desired quality of each cascade.
This is default option.
Fields
Relative
Camera frustum will be split into a CSM_NUM_CASCADES splits using provided fractions.
This option might give lesser quality results with camera that have large far plane, however it does not require any precise tweaking.
Implementations
Sourceimpl FrustumSplitOptions
impl FrustumSplitOptions
pub const ABSOLUTE_FAR_PLANES: &'static str = "Absolute@far_planes"
pub const RELATIVE_FRACTIONS: &'static str = "Relative@fractions"