pub struct DirectionalLightBuilder { /* private fields */ }Expand description
Allows you to build directional light in declarative manner.
Implementations
Sourceimpl DirectionalLightBuilder
impl DirectionalLightBuilder
Sourcepub fn new(base_light_builder: BaseLightBuilder) -> Self
pub fn new(base_light_builder: BaseLightBuilder) -> Self
Creates new builder instance.
Sourcepub fn build_directional_light(self) -> DirectionalLight
pub fn build_directional_light(self) -> DirectionalLight
Creates new instance of directional light.
Sourcepub fn with_csm_options(self, csm_options: CsmOptions) -> Self
pub fn with_csm_options(self, csm_options: CsmOptions) -> Self
Sets desired options for cascaded shadow maps.
Sourcepub fn build_node(self) -> Node
pub fn build_node(self) -> Node
Creates new instance of directional light node.
Sourcepub fn build(self, graph: &mut Graph) -> Handle<DirectionalLight>
pub fn build(self, graph: &mut Graph) -> Handle<DirectionalLight>
Creates new instance of directional light and adds it to the graph.