Module surface

Module surface 

Surface is a set of triangles with a single material. Such arrangement makes GPU rendering very efficient. See Surface docs for more info and usage examples.

Structs

BlendShape
A target shape for blending.
BlendShapesContainer
A container for multiple blend shapes/
InputBlendShapeData
A set of offsets for particular vertices.
Surface
Surface is a set of triangles with a single material. Such arrangement makes GPU rendering very efficient.
SurfaceBuilder
Surface builder allows you to create surfaces in declarative manner.
SurfaceData
Data source of a surface. Each surface can share same data source, this is used in instancing technique to render multiple instances of same model at different places.
SurfaceDataLoader
Default surface resource loader.
VertexWeight
Vertex weight is a pair of (bone; weight) that affects vertex.
VertexWeightSet
Weight set contains up to four pairs of (bone; weight).

Statics

CONE
Cone surface resource.
CUBE
Cube surface resource.
CYLINDER
Cylinder surface resource.
QUAD
Quad surface resource.
SPHERE
Sphere surface resource.
TORUS
Torus surface resource.

Traits

SurfaceResourceExtension
A trait with extension methods for surface resource.

Type Aliases

SurfaceResource
Surface shared data is a vertex and index buffer that can be shared across multiple objects. This is very useful memory optimization - you create a single data storage for a surface and then share it with any instance count you want. Memory usage does not increase with instance count in this case.