SurfaceResource

Type Alias SurfaceResource 

pub type SurfaceResource = Resource<SurfaceData>;
Surface shared data is a vertex and index buffer that can be shared across multiple objects. This is very useful memory optimization - you create a single data storage for a surface and then share it with any instance count you want. Memory usage does not increase with instance count in this case.

Aliased Type

pub struct SurfaceResource { /* private fields */ }