pub struct ParticleSystemBuilder { /* private fields */ }Expand description
Particle system builder allows you to construct particle system in declarative manner. This is typical implementation of Builder pattern.
Implementations
Sourceimpl ParticleSystemBuilder
impl ParticleSystemBuilder
Sourcepub fn new(base_builder: BaseBuilder) -> Self
pub fn new(base_builder: BaseBuilder) -> Self
Creates new builder with default parameters.
Sourcepub fn with_emitters(self, emitters: Vec<Emitter>) -> Self
pub fn with_emitters(self, emitters: Vec<Emitter>) -> Self
Sets desired emitters for particle system.
Sourcepub fn with_material(self, material: MaterialResource) -> Self
pub fn with_material(self, material: MaterialResource) -> Self
Sets desired material for particle system.
Sourcepub fn with_acceleration(self, acceleration: Vector3<f32>) -> Self
pub fn with_acceleration(self, acceleration: Vector3<f32>) -> Self
Sets desired acceleration for particle system.
Sourcepub fn with_visible_distance(self, distance: f32) -> Self
pub fn with_visible_distance(self, distance: f32) -> Self
Sets the desired visible distance for the particle system. See ParticleSystem::set_visible_distance
for more info.
Sourcepub fn with_color_over_lifetime_gradient(
self,
color_over_lifetime: ColorGradient,
) -> Self
pub fn with_color_over_lifetime_gradient( self, color_over_lifetime: ColorGradient, ) -> Self
Sets color gradient over lifetime for particle system.
Sourcepub fn with_particles(self, particles: Vec<Particle>) -> Self
pub fn with_particles(self, particles: Vec<Particle>) -> Self
Sets an initial set of particles that not belongs to any emitter. This method could be useful if you need a custom position/velocity/etc. of each particle.
Sourcepub fn with_playing(self, enabled: bool) -> Self
pub fn with_playing(self, enabled: bool) -> Self
Sets initial particle system state.
Sourcepub fn with_rng(self, rng: ParticleSystemRng) -> Self
pub fn with_rng(self, rng: ParticleSystemRng) -> Self
Sets desired pseudo-random numbers generator.
Sourcepub fn with_coordinate_system(self, coordinate_system: CoordinateSystem) -> Self
pub fn with_coordinate_system(self, coordinate_system: CoordinateSystem) -> Self
Sets the desired coordinate system for particles.
Sourcepub fn with_fadeout_margin(self, margin: f32) -> Self
pub fn with_fadeout_margin(self, margin: f32) -> Self
Sets a margin value in which the distance fading will occur.
Sourcepub fn build_node(self) -> Node
pub fn build_node(self) -> Node
Creates new instance of particle system.
Sourcepub fn build(self, graph: &mut Graph) -> Handle<ParticleSystem>
pub fn build(self, graph: &mut Graph) -> Handle<ParticleSystem>
Creates new instance of particle system and adds it to the graph.