Module probe

Module probe 

Reflection probe is an object that allows “capturing” a scene content in a cube texture, that can later be used to render reflections and be used as a source of ambient lighting for a scene. See ReflectionProbe docs for more info.

Structs

ReflectionProbe
Reflection probe is an object that allows “capturing” a scene content in a cube texture, that can later be used to render reflections and be used as a source of ambient lighting for a scene.
ReflectionProbeBuilder
Allows you to create a reflection probe node declaratively.

Enums

UpdateMode
Update mode of reflection probes.