#[repr(u32)]pub enum RigidBodyType {
Dynamic = 0,
Static = 1,
KinematicPositionBased = 2,
KinematicVelocityBased = 3,
}Expand description
A set of possible types of rigid body.
Variants
Dynamic = 0
Dynamic rigid bodies can be affected by external forces.
Static = 1
Static rigid bodies cannot be affected by external forces.
KinematicPositionBased = 2
Kinematic rigid body cannot be affected by external forces, but can push other rigid bodies. It also does not have any dynamic, you are able to control the position manually.
KinematicVelocityBased = 3
Kinematic rigid body cannot be affected by external forces, but can push other rigid bodies. It also does not have any dynamic, you are able to control the position by changing velocity.