pub struct SkyBoxBuilder {
pub front: Option<TextureResource>,
pub back: Option<TextureResource>,
pub left: Option<TextureResource>,
pub right: Option<TextureResource>,
pub top: Option<TextureResource>,
pub bottom: Option<TextureResource>,
}Expand description
SkyBox builder is used to create new skybox in declarative manner.
Fields
front: Option<TextureResource>Texture for front face.
back: Option<TextureResource>Texture for back face.
left: Option<TextureResource>Texture for left face.
right: Option<TextureResource>Texture for right face.
top: Option<TextureResource>Texture for top face.
bottom: Option<TextureResource>Texture for bottom face.
Implementations
Sourceimpl SkyBoxBuilder
impl SkyBoxBuilder
Sourcepub fn from_texture(texture: &TextureResource) -> Self
pub fn from_texture(texture: &TextureResource) -> Self
Creates a new builder, where each texture for each side of the sky box is the same.
Sourcepub fn with_front(self, texture: TextureResource) -> Self
pub fn with_front(self, texture: TextureResource) -> Self
Sets desired front face of cubemap.
Sourcepub fn with_back(self, texture: TextureResource) -> Self
pub fn with_back(self, texture: TextureResource) -> Self
Sets desired back face of cubemap.
Sourcepub fn with_left(self, texture: TextureResource) -> Self
pub fn with_left(self, texture: TextureResource) -> Self
Sets desired left face of cubemap.
Sourcepub fn with_right(self, texture: TextureResource) -> Self
pub fn with_right(self, texture: TextureResource) -> Self
Sets desired right face of cubemap.
Sourcepub fn with_top(self, texture: TextureResource) -> Self
pub fn with_top(self, texture: TextureResource) -> Self
Sets desired top face of cubemap.
Sourcepub fn with_bottom(self, texture: TextureResource) -> Self
pub fn with_bottom(self, texture: TextureResource) -> Self
Sets desired front face of cubemap.
Sourcepub fn build(self) -> Result<SkyBox, SkyBoxError>
pub fn build(self) -> Result<SkyBox, SkyBoxError>
Creates a new instance of skybox.