HrirSphere

Struct HrirSphere 

pub struct HrirSphere { /* private fields */ }
HRIR (Head-Related Impulse Response) spheres is a 3d mesh whose points contains impulse responses for left and right ears. It is used for interpolation of impulse responses.

Implementations

Source

impl HrirSphere

pub fn from_file<P>( path: P, device_sample_rate: u32, ) -> Result<HrirSphere, HrtfError>
where P: AsRef<Path>,

Tries to load a sphere from a file.

pub fn new<R>( reader: R, device_sample_rate: u32, ) -> Result<HrirSphere, HrtfError>
where R: Read,

Loads HRIR sphere from given source.

Coordinate system

Hrtf spheres made in right-handed coordinate system. This fact can give weird positioning issues if your application uses left-handed coordinate system. However this can be fixed very easily: iterate over every point and invert X coordinate of it.

Sample rate

HRIR spheres from this base recorded in 44100 Hz sample rate. If your output device uses different sample rate, you have to resample initial set of .wav files and regenerate HRIR spheres. There could

pub fn transform(&mut self, matrix: &[f32; 16])

Applies specified transform to each point in sphere. Can be used to rotate or scale sphere. Transform shouldn’t have translation part, otherwise result of bilinear sampling is undefined.

pub fn points(&self) -> &[HrirPoint]

Returns shared reference to sphere points array.

pub fn points_mut(&mut self) -> &mut [HrirPoint]

Returns mutable reference to sphere points array.

pub fn len(&self) -> usize

Returns length of impulse response. It is same across all points in the sphere.

pub fn source(&self) -> &Path

Returns source file name (if any).