pub trait HrirSphereResourceExt {
// Required method
fn from_hrir_sphere(hrir_sphere: HrirSphere, kind: ResourceKind) -> Self;
}Expand description
A set of extension methods for HrirSphereResource
Required Methods
Sourcefn from_hrir_sphere(hrir_sphere: HrirSphere, kind: ResourceKind) -> Self
fn from_hrir_sphere(hrir_sphere: HrirSphere, kind: ResourceKind) -> Self
Creates a new HRIR sphere resource directly from pre-loaded HRIR sphere. It could be used if you do not use a resource manager, but want to load HRIR spheres manually.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.