Chunk

Struct Chunk 

pub struct Chunk {
    pub layer_masks: Vec<TextureResource>,
    /* private fields */
}
Chunk is smaller block of a terrain. Terrain can have as many chunks as you need, which always arranged in a grid. You can add chunks from any side of a terrain. Chunks could be considered as a “sub-terrain”, which could use its own set of materials for layers. This could be useful for different biomes, to prevent high amount of layers which could harm the performance.

Fields

layer_masks: Vec<TextureResource>

Layer blending masks of the chunk.

Implementations

Source

impl Chunk

pub const HEIGHTMAP: &'static str = "heightmap"

Source

impl Chunk

pub fn height_data(&self) -> ChunkHeightData<'_>

Return a view of the height data as a 2D array of f32.

pub fn create_margin(&mut self)

Modify the height texture of the chunk to give it a one pixel margin around all four edges. The Chunk::height_map_size is increased to match. The margin is initialized to zero.

pub fn update(&self)

Check the heightmap for modifications and update data as necessary.

pub fn local_position(&self) -> Vector2<f32>

Returns position of the chunk in local 2D coordinates relative to origin of the terrain.

pub fn position(&self) -> Vector3<f32>

The position of the chunk within the terrain based on its grid_position and physical_size.

pub fn grid_position(&self) -> Vector2<i32>

The 2D position of the chunk within the chunk array.

pub fn heightmap(&self) -> &TextureResource

Returns a reference to height map.

pub fn set_height_map( &mut self, height_map: Option<TextureResource>, ) -> Option<TextureResource>

Sets new height map to the chunk. Tries to create a copy of the given texture and convert the copy into R32F format. If the conversion is successful, the resulting texture becomes the source for height data of this chunk and the new texture is returned. If the conversion fails, the argument texture is returned in its original format and the chunk is not modified.

Failure can happen if:

  • The given texture is None.
  • The given texture is not in the Ok state.
  • The given texture is not TextureKind::Rectangle.
  • The width or height is incorrect due to not matching height_map_size.
  • The texture’s format is not one of the many formats that this method is capable of converting as identified by its Texture::pixel_kind.
pub fn heightmap_owned(&self) -> Vec<f32>

Returns the height map of the terrain as an array of f32s.

pub fn replace_height_map( &mut self, heightmap: TextureResource, ) -> Result<(), TextureResource>

Replaces the current height map with a new one. New height map must be equal with size of current.

pub fn hole_mask(&self) -> Option<&TextureResource>

Returns a reference to hole mask texture, if one exists.

pub fn physical_size(&self) -> Vector2<f32>

Returns the size of the chunk in meters.

pub fn height_map_size(&self) -> Vector2<u32>

Returns amount of pixels in the height map along each dimension.

pub fn hole_mask_size(&self) -> Vector2<u32>

Returns amount of pixels in the hole mask along each dimension.

pub fn debug_draw( &self, transform: &Matrix4<f32>, ctx: &mut SceneDrawingContext, )

Performs debug drawing of the chunk. It draws internal quad-tree structure for debugging purposes.

pub fn update_quad_tree(&self)

Recalculates the quad tree for this chunk.