pub struct TileMapBrush {
pub tile_set: Option<TileSetResource>,
pub pages: TileGridMap<TileMapBrushPage>,
pub change_count: ChangeFlag,
}Expand description
Tile map brush is a set of tiles arranged in arbitrary shape, that can be used to draw on a tile map.
Fields
tile_set: Option<TileSetResource>The tile set used by this brush. This must match the tile set of any tile map that this brush is used to edit.
pages: TileGridMap<TileMapBrushPage>The set of pages contained in the brush Each page is associated with 2D coordinates within a palette of brush pages. This allows pages to be selected much like tiles are selected, and it allows users to customize the organization of pages.
change_count: ChangeFlagA count of changes since last save. New changes add +1. Reverting to previous states add -1. Reverting to a state before the last save can result in negative values. Saving is unnecessary whenever this value is 0.
Implementations
Sourceimpl TileMapBrush
impl TileMapBrush
Sourcepub fn has_tile_at(&self, page: Vector2<i32>, tile: Vector2<i32>) -> bool
pub fn has_tile_at(&self, page: Vector2<i32>, tile: Vector2<i32>) -> bool
True if there is a tile at the given position.
Sourcepub fn has_page_at(&self, page: Vector2<i32>) -> bool
pub fn has_page_at(&self, page: Vector2<i32>) -> bool
True if there is a page at the given position.
Sourcepub fn tile_redirect(
&self,
handle: TileDefinitionHandle,
) -> Option<TileDefinitionHandle>
pub fn tile_redirect( &self, handle: TileDefinitionHandle, ) -> Option<TileDefinitionHandle>
The handle stored at the given position.
Sourcepub fn pages_bounds(&self) -> OptionTileRect
pub fn pages_bounds(&self) -> OptionTileRect
Returns bounding rectangle of pages in grid coordinates.
Sourcepub fn page_icon(&self, page: Vector2<i32>) -> Option<TileDefinitionHandle>
pub fn page_icon(&self, page: Vector2<i32>) -> Option<TileDefinitionHandle>
The handle of the tile that represents the page at the given position.
Sourcepub fn tiles_bounds(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
) -> OptionTileRect
pub fn tiles_bounds( &self, stage: TilePaletteStage, page: Vector2<i32>, ) -> OptionTileRect
The bounds of the tiles on the given page.
Sourcepub fn find_tile_at_position(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
position: Vector2<i32>,
) -> Option<TileDefinitionHandle>
pub fn find_tile_at_position( &self, stage: TilePaletteStage, page: Vector2<i32>, position: Vector2<i32>, ) -> Option<TileDefinitionHandle>
The handle of the tile at the given position, either the icon of a page or the tile stored at that position in the brush.
Sourcepub fn get_tiles<I: Iterator<Item = Vector2<i32>>>(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
iter: I,
tiles: &mut Tiles,
)
pub fn get_tiles<I: Iterator<Item = Vector2<i32>>>( &self, stage: TilePaletteStage, page: Vector2<i32>, iter: I, tiles: &mut Tiles, )
The tile definition handles of the tiles at the given positions on the given page.
Sourcepub fn is_missing_tile_set(&self) -> bool
pub fn is_missing_tile_set(&self) -> bool
Return true if this brush has no tile set.
Sourcepub fn palette_render_loop<F>(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
func: F,
)
pub fn palette_render_loop<F>( &self, stage: TilePaletteStage, page: Vector2<i32>, func: F, )
Loops through the tiles of the given page and finds the render data for each tile in the tile set, then passes it to the given function.
Sourcepub fn get_tile_render_data(
&self,
position: ResourceTilePosition,
) -> Option<TileRenderData>
pub fn get_tile_render_data( &self, position: ResourceTilePosition, ) -> Option<TileRenderData>
Return the TileRenderData needed to render the tile at the given position on the given page.
If there is no tile at that position or the tile set is missing or not loaded, then None is returned.
If there is a tile and a tile set, but the handle of the tile does not exist in the tile set,
then the rendering data for an error tile is returned using TileRenderData::missing_tile().
Sourcepub fn redirect_handle(
&self,
position: ResourceTilePosition,
) -> Option<TileDefinitionHandle>
pub fn redirect_handle( &self, position: ResourceTilePosition, ) -> Option<TileDefinitionHandle>
The tiles of a brush are references to tiles in the tile set. This method converts positions within the brush into the handle that points to the corresponding tile definition within the tile set. If this brush does not contain a reference at the given position, then None is returned.
Sourcepub fn get_tile_bounds(
&self,
position: ResourceTilePosition,
) -> Option<TileMaterialBounds>
pub fn get_tile_bounds( &self, position: ResourceTilePosition, ) -> Option<TileMaterialBounds>
The TileMaterialBounds taken from the tile set for the tile in the brush at the given position.
Sourcepub async fn from_file(
path: &Path,
resource_manager: ResourceManager,
io: &dyn ResourceIo,
) -> Result<Self, TileMapBrushResourceError>
pub async fn from_file( path: &Path, resource_manager: ResourceManager, io: &dyn ResourceIo, ) -> Result<Self, TileMapBrushResourceError>
Load a tile map brush resource from the specific file path.