pub struct TileBounds {
pub left_top_corner: Vector2<u32>,
pub right_top_corner: Vector2<u32>,
pub right_bottom_corner: Vector2<u32>,
pub left_bottom_corner: Vector2<u32>,
}Expand description
Specify the pixel coordinates of each corner of a tile within some material.
This is used in place of a standard Rect because tiles can be flipped and rotated
and otherwise transformed with respect the their source material, so for example the
left-top corner of the tile may be to the right of the right-top corner in the material.
Fields
left_top_corner: Vector2<u32>The position of the tile’s left-top corner within its source material.
right_top_corner: Vector2<u32>The position of the tile’s right-top corner within its source material.
right_bottom_corner: Vector2<u32>The position of the tile’s left-bottom corner within its source material.
left_bottom_corner: Vector2<u32>The position of the tile’s right-bottom corner within its source material.
Implementations
Sourceimpl TileBounds
impl TileBounds
pub const LEFT_TOP_CORNER: &'static str = "left_top_corner"
pub const RIGHT_TOP_CORNER: &'static str = "right_top_corner"
pub const RIGHT_BOTTOM_CORNER: &'static str = "right_bottom_corner"
pub const LEFT_BOTTOM_CORNER: &'static str = "left_bottom_corner"
Sourceimpl TileBounds
impl TileBounds
Sourcepub fn left_top_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
pub fn left_top_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
Translates the pixel position of the corner of the tile into UV coordinates between 0 and 1.
Sourcepub fn right_top_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
pub fn right_top_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
Translates the pixel position of the corner of the tile into UV coordinates between 0 and 1.
Sourcepub fn left_bottom_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
pub fn left_bottom_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
Translates the pixel position of the corner of the tile into UV coordinates between 0 and 1.
Sourcepub fn right_bottom_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
pub fn right_bottom_uv(&self, texture_size: Vector2<u32>) -> Vector2<f32>
Translates the pixel position of the corner of the tile into UV coordinates between 0 and 1.