pub struct TileData {
pub colliders: FxHashMap<Uuid, TileCollider>,
pub color: Color,
pub properties: FxHashMap<Uuid, TileSetPropertyValue>,
}Expand description
Miscellaneous data that is stored with the tile definition.
Fields
colliders: FxHashMap<Uuid, TileCollider>Colliders of the tile.
color: ColorColor of the tile.
properties: FxHashMap<Uuid, TileSetPropertyValue>A custom set of properties. Properties could be used to assign additional information for tiles, such surface type (for example, lava, ice, dirt, etc.), physics properties and so on.
Implementations