TileSetPage

Struct TileSetPage 

pub struct TileSetPage {
    pub icon: TileDefinitionHandle,
    pub source: TileSetPageSource,
}
A tile set can contain multiple pages of tiles, and each page may have its own independent source of tile data.

Fields

icon: TileDefinitionHandle

The tile that represents this page in the editor

source: TileSetPageSource

The source of the page’s data.

Implementations

Source

impl TileSetPage

pub const ICON: &'static str = "icon"

pub const SOURCE: &'static str = "source"

Source

impl TileSetPage

pub fn is_material(&self) -> bool

True if this page is a material page.

pub fn is_freeform(&self) -> bool

True if this page is a freeform tile page.

pub fn is_transform_set(&self) -> bool

True if this page contains tile transform groups.

pub fn is_animation(&self) -> bool

True if this page contains tile transform groups.

pub fn page_type(&self) -> PageType

The type of this page.

pub fn has_tile_at(&self, position: Vector2<i32>) -> bool

True if a tile exists at the given position in this page.

pub fn keys(&self) -> Vec<Vector2<i32>>

Generate a list of all tile positions in this page.

pub fn get_bounds(&self) -> OptionTileRect

The rect that contains all the tiles of this page.

pub fn swap_tile(&mut self, position: Vector2<i32>, update: &mut TileDataUpdate)

Change this tile set according to the specifications in update, and change update so that it would refers the change to this tile set, if it were applied again at the same position.

pub fn swap_all_values_for_property( &mut self, page: Vector2<i32>, property_id: Uuid, values: &mut FxHashMap<TileDefinitionHandle, TileSetPropertyValue>, )

Take all the values for the property with the given id, remove them from the page, and put them into the given hash map. At the same time, take all the values from the given hash map and put them into the page.

pub fn swap_all_values_for_collider( &mut self, page: Vector2<i32>, collider_id: Uuid, values: &mut FxHashMap<TileDefinitionHandle, TileCollider>, )

Take all the colliders for the given collider id, remove them from the page, and put them into the given hash map. At the same time, take all the colliders from the given hash map and put them into the page.