pub trait BoundedTileSource: TileSource {
// Required method
fn bounding_rect(&self) -> OptionTileRect;
}Expand description
A trait for types that can produce a TileDefinitionHandle upon demand, for use with drawing on tilemaps.
Required Methods
Sourcefn bounding_rect(&self) -> OptionTileRect
fn bounding_rect(&self) -> OptionTileRect
Calculates bounding rectangle in grid coordinates.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".