TileMapEffect

Trait TileMapEffect 

pub trait TileMapEffect: Send + Debug {
    // Required method
    fn render_special_tiles(&self, context: &mut TileMapRenderContext<'_, '_>);
}
A trait for objects that can perform specialized rendering for a tile map by adding them to TileMap::before_effects or TileMap::after_effects, depending on whether the effect should render before the tile map renders or after the tile map renders.

Required Methods

fn render_special_tiles(&self, context: &mut TileMapRenderContext<'_, '_>)

Use the given context to render the special effect for the TileMap.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors