pub type TileTerrainId = i8;Expand description
A value that specifies the terrain of a tile map cell for auto-tiling. This value comes from the center of a nine-slice tile set property, so it can constrain which tiles are permitted in a particular cell.