pub struct Transform { /* private fields */ }Expand description
See module docs.
Implementations
Sourceimpl Transform
impl Transform
pub const LOCAL_SCALE: &'static str = "local_scale"
pub const LOCAL_POSITION: &'static str = "local_position"
pub const LOCAL_ROTATION: &'static str = "local_rotation"
pub const PRE_ROTATION: &'static str = "pre_rotation"
pub const POST_ROTATION: &'static str = "post_rotation"
pub const ROTATION_OFFSET: &'static str = "rotation_offset"
pub const ROTATION_PIVOT: &'static str = "rotation_pivot"
pub const SCALING_OFFSET: &'static str = "scaling_offset"
pub const SCALING_PIVOT: &'static str = "scaling_pivot"
Sourceimpl Transform
impl Transform
Sourcepub fn identity() -> Self
pub fn identity() -> Self
Creates new transform that has no effect, in other words any vector or matrix will remain unchanged if combined with identity transform.
Sourcepub fn position(&self) -> &InheritableVariable<Vector3<f32>>
pub fn position(&self) -> &InheritableVariable<Vector3<f32>>
Returns current position of transform.
Sourcepub fn set_position(&mut self, local_position: Vector3<f32>) -> &mut Self
pub fn set_position(&mut self, local_position: Vector3<f32>) -> &mut Self
Sets position of transform.
Sourcepub fn rotation(&self) -> &InheritableVariable<UnitQuaternion<f32>>
pub fn rotation(&self) -> &InheritableVariable<UnitQuaternion<f32>>
Returns current rotation quaternion of transform.
Sourcepub fn set_rotation(&mut self, local_rotation: UnitQuaternion<f32>) -> &mut Self
pub fn set_rotation(&mut self, local_rotation: UnitQuaternion<f32>) -> &mut Self
Sets rotation of transform.
Sourcepub fn scale(&self) -> &InheritableVariable<Vector3<f32>>
pub fn scale(&self) -> &InheritableVariable<Vector3<f32>>
Returns current scale factor of transform.
Sourcepub fn set_pre_rotation(
&mut self,
pre_rotation: UnitQuaternion<f32>,
) -> &mut Self
pub fn set_pre_rotation( &mut self, pre_rotation: UnitQuaternion<f32>, ) -> &mut Self
Sets pre-rotation of transform. Usually pre-rotation can be used to change “coordinate” system of transform. It is mostly for FBX compatibility, and never used in other places of engine.
Sourcepub fn pre_rotation(&self) -> &InheritableVariable<UnitQuaternion<f32>>
pub fn pre_rotation(&self) -> &InheritableVariable<UnitQuaternion<f32>>
Returns current pre-rotation of transform.
Sourcepub fn set_post_rotation(
&mut self,
post_rotation: UnitQuaternion<f32>,
) -> &mut Self
pub fn set_post_rotation( &mut self, post_rotation: UnitQuaternion<f32>, ) -> &mut Self
Sets post-rotation of transform. Usually post-rotation can be used to change “coordinate” system of transform. It is mostly for FBX compatibility, and never used in other places of engine.
Sourcepub fn post_rotation(&self) -> &InheritableVariable<UnitQuaternion<f32>>
pub fn post_rotation(&self) -> &InheritableVariable<UnitQuaternion<f32>>
Returns current post-rotation of transform.
Sourcepub fn set_rotation_offset(
&mut self,
rotation_offset: Vector3<f32>,
) -> &mut Self
pub fn set_rotation_offset( &mut self, rotation_offset: Vector3<f32>, ) -> &mut Self
Sets rotation offset of transform. Moves rotation pivot using given vector, it results in rotation being performed around rotation pivot with some offset.
Sourcepub fn rotation_offset(&self) -> &InheritableVariable<Vector3<f32>>
pub fn rotation_offset(&self) -> &InheritableVariable<Vector3<f32>>
Returns current rotation offset of transform.
Sourcepub fn set_rotation_pivot(&mut self, rotation_pivot: Vector3<f32>) -> &mut Self
pub fn set_rotation_pivot(&mut self, rotation_pivot: Vector3<f32>) -> &mut Self
Sets rotation pivot of transform. This method sets a point around which all rotations will be performed. For example it can be used to rotate a cube around its vertex.
Sourcepub fn rotation_pivot(&self) -> &InheritableVariable<Vector3<f32>>
pub fn rotation_pivot(&self) -> &InheritableVariable<Vector3<f32>>
Returns current rotation pivot of transform.
Sourcepub fn set_scaling_offset(&mut self, scaling_offset: Vector3<f32>) -> &mut Self
pub fn set_scaling_offset(&mut self, scaling_offset: Vector3<f32>) -> &mut Self
Sets scaling offset. Scaling offset defines offset from position of scaling pivot.
Sourcepub fn scaling_offset(&self) -> &InheritableVariable<Vector3<f32>>
pub fn scaling_offset(&self) -> &InheritableVariable<Vector3<f32>>
Returns current scaling offset of transform.
Sourcepub fn set_scaling_pivot(&mut self, scaling_pivot: Vector3<f32>) -> &mut Self
pub fn set_scaling_pivot(&mut self, scaling_pivot: Vector3<f32>) -> &mut Self
Sets scaling pivot. Scaling pivot sets a point around which scale will be performed.
Sourcepub fn scaling_pivot(&self) -> &InheritableVariable<Vector3<f32>>
pub fn scaling_pivot(&self) -> &InheritableVariable<Vector3<f32>>
Returns current scaling pivot of transform.