pub struct Script { /* private fields */ }Expand description
A wrapper for actual script instance internals, it used by the engine.
Implementations
Sourceimpl Script
impl Script
Sourcepub fn new<T: ScriptTrait>(script_object: T) -> Self
pub fn new<T: ScriptTrait>(script_object: T) -> Self
Creates new script wrapper using given script instance.
Sourcepub fn summary(&self) -> String
pub fn summary(&self) -> String
Generate a brief summary of this script for debugging purposes.
Sourcepub fn cast<T: ScriptTrait>(&self) -> Option<&T>
pub fn cast<T: ScriptTrait>(&self) -> Option<&T>
Performs downcasting to a particular type.
Sourcepub fn cast_mut<T: ScriptTrait>(&mut self) -> Option<&mut T>
pub fn cast_mut<T: ScriptTrait>(&mut self) -> Option<&mut T>
Performs downcasting to a particular type.
Sourcepub fn query_component_ref<T: Any>(&self) -> Option<&T>
pub fn query_component_ref<T: Any>(&self) -> Option<&T>
Tries to borrow a component of given type.
Sourcepub fn query_component_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn query_component_mut<T: Any>(&mut self) -> Option<&mut T>
Tries to borrow a component of given type.