pub struct Lightmap {
pub texture_name: String,
pub second_tex_coord_location: u8,
pub map: FxHashMap<Handle<Node>, Vec<LightmapEntry>>,
pub patches: FxHashMap<u64, SurfaceDataPatchWrapper>,
}Expand description
Lightmap is a texture with precomputed lighting.
Fields
texture_name: StringName of the property this light map is bound to in all materials across all surfaces for which the light map was generated.
second_tex_coord_location: u8Location of the second texture coordinate attribute in the vertex buffer of all surfaces.
map: FxHashMap<Handle<Node>, Vec<LightmapEntry>>Node handle to lightmap mapping. It is used to quickly get information about lightmaps for any node in scene.
patches: FxHashMap<u64, SurfaceDataPatchWrapper>List of surface data patches. Each patch will be applied to corresponding surface data on resolve stage.
Implementations
Sourceimpl Lightmap
impl Lightmap
pub const TEXTURE_NAME: &'static str = "texture_name"
pub const SECOND_TEX_COORD_LOCATION: &'static str = "second_tex_coord_location"
pub const MAP: &'static str = "map"
Sourceimpl Lightmap
impl Lightmap
Sourcepub async fn load<P: AsRef<Path>>(
path: P,
resource_manager: ResourceManager,
) -> Result<Lightmap, VisitError>
pub async fn load<P: AsRef<Path>>( path: P, resource_manager: ResourceManager, ) -> Result<Lightmap, VisitError>
Loads a light map from the given path.
Sourcepub fn save<P: AsRef<Path>>(&mut self, path: P) -> VisitResult
pub fn save<P: AsRef<Path>>(&mut self, path: P) -> VisitResult
Saves a light map to the given file. Keep in mind, that the textures should be saved separately first, via
Self::save_textures method.
Sourcepub fn new(
data: LightmapInputData,
texels_per_unit: u32,
uv_spacing: f32,
cancellation_token: CancellationToken,
progress_indicator: ProgressIndicator,
) -> Result<Self, LightmapGenerationError>
pub fn new( data: LightmapInputData, texels_per_unit: u32, uv_spacing: f32, cancellation_token: CancellationToken, progress_indicator: ProgressIndicator, ) -> Result<Self, LightmapGenerationError>
Generates lightmap for given scene. This method automatically generates secondary texture coordinates! This method is blocking, however internally it uses massive parallelism to use all available CPU power efficiently.
texels_per_unit defines resolution of lightmap, the higher value is, the more quality
lightmap will be generated, but also it will be slow to generate.
progress_indicator allows you to get info about current progress.
cancellation_token allows you to stop generation in any time.
Sourcepub fn save_textures<P: AsRef<Path>>(
&self,
base_path: P,
resource_manager: ResourceManager,
) -> Result<(), ResourceRegistrationError>
pub fn save_textures<P: AsRef<Path>>( &self, base_path: P, resource_manager: ResourceManager, ) -> Result<(), ResourceRegistrationError>
Saves lightmap textures into specified folder.