Built-in resource is a resource embedded in the application executable file. It is a very useful
mechanism when you need to bundle all game resources and put them in the executable file. See
BuiltInResource docs for more info.
Structs
- Built
InResource - Built-in resource is a resource embedded in the application executable file. It is a very useful mechanism when you need to bundle all game resources and put them in the executable file.
- Built
InResources Container - A container for built-in resources. Every built-in resource is registered using its id defined at the creation stage.
- Data
Source - Data source of a built-in resource.
- Untyped
Built InResource - Untyped built-in resource.