Resource manager controls loading and lifetime of resource in the engine. See ResourceManager
docs for more info.
Structs
- Built
InResource - Built-in resource is a resource embedded in the application executable file. It is a very useful mechanism when you need to bundle all game resources and put them in the executable file.
- Built
InResources Container - A container for built-in resources. Every built-in resource is registered using its id defined at the creation stage.
- Data
Source - Data source of a built-in resource.
- Resource
Manager - Resource manager controls loading and lifetime of resource in the engine. Resource manager can hold resources of arbitrary types via type erasure mechanism.
- Resource
Manager State - Internal state of the resource manager.
- Resource
Move Context - All the required and validated data that is needed to move a resource from the path A to the path B.
- Resource
Wait Context - A set of resources that can be waited for.
- Untyped
Built InResource - Untyped built-in resource.
Enums
- Folder
Movement Error - A set of potential errors that may occur when moving a folder with resources.
- Resource
Movement Error - A possible set of errors that may occur during resource movement.
- Resource
Registration Error - An error that may occur during texture registration.