pub struct ResourceRegistry {
pub excluded_folders: HashSet<PathBuf, BuildHasherDefault<FxHasher>>,
/* private fields */
}Expand description
Resource registry is responsible for UUID mapping of resource files. It maintains a map of
UUID -> Resource Path.
Fields
excluded_folders: HashSet<PathBuf, BuildHasherDefault<FxHasher>>A list of folder that should be excluded when scanning the project folder for supported
resources. By default, it contains ./target (a folder with build artifacts) and ./build
(a folder with production builds) folders.
Implementations
Sourceimpl ResourceRegistry
impl ResourceRegistry
Sourcepub const DEFAULT_PATH: &'static str = "data/resources.registry"
pub const DEFAULT_PATH: &'static str = "data/resources.registry"
Default path of the registry. It can be overridden on a registry instance using
Self::set_path method.
Sourcepub fn new(io: Arc<dyn ResourceIo>) -> ResourceRegistry
pub fn new(io: Arc<dyn ResourceIo>) -> ResourceRegistry
Creates a new resource registry with the given resource IO.
Sourcepub fn status_flag(&self) -> ResourceRegistryStatusFlag
pub fn status_flag(&self) -> ResourceRegistryStatusFlag
Returns a shared reference to the status flag. See ResourceRegistryStatusFlag docs for
more info.
Sourcepub fn normalize_path(&self, path: impl AsRef<Path>) -> PathBuf
pub fn normalize_path(&self, path: impl AsRef<Path>) -> PathBuf
Normalizes the path by resolving all . and .. and removing any prefixes.
Absolute paths are converted to relative paths by removing the project root prefix, if possible.
Also replaces \\ slashes to cross-platform / slashes.
Panics
Panics if the given path is invalid, such as if it includes a directory that does not exist.
Sourcepub fn inner(&self) -> &BTreeMap<Uuid, PathBuf>
pub fn inner(&self) -> &BTreeMap<Uuid, PathBuf>
Returns a reference to the actual container of the resource entries.
Sourcepub fn set_path(&mut self, path: impl AsRef<Path>)
pub fn set_path(&mut self, path: impl AsRef<Path>)
Sets a new path for the registry, but does not saves it.
Sourcepub fn path(&self) -> &Path
pub fn path(&self) -> &Path
Returns a path to which the resource registry is (or may) be saved.
Sourcepub fn directory(&self) -> Option<&Path>
pub fn directory(&self) -> Option<&Path>
Returns a directory to which the resource registry is (or may) be saved.
Sourcepub fn exists_sync(&self) -> bool
pub fn exists_sync(&self) -> bool
Returns true if the resource registry file exists, false - otherwise.
Sourcepub fn save_sync(&self)
pub fn save_sync(&self)
Same as Self::save, but synchronous.
Sourcepub fn modify(&mut self) -> ResourceRegistryRefMut<'_>
pub fn modify(&mut self) -> ResourceRegistryRefMut<'_>
Begins registry modification. See ResourceRegistryRefMut docs for more info.
Sourcepub fn uuid_to_path(&self, uuid: Uuid) -> Option<&Path>
pub fn uuid_to_path(&self, uuid: Uuid) -> Option<&Path>
Tries to get a path associated with the given resource UUID.
Sourcepub fn uuid_to_path_buf(&self, uuid: Uuid) -> Option<PathBuf>
pub fn uuid_to_path_buf(&self, uuid: Uuid) -> Option<PathBuf>
Same as Self::uuid_to_path, but returns PathBuf instead of &Path.
Sourcepub fn path_to_uuid(&self, path: &Path) -> Option<Uuid>
pub fn path_to_uuid(&self, path: &Path) -> Option<Uuid>
Tries to find a UUID that corresponds for the given path.
Sourcepub fn is_registered(&self, path: &Path) -> bool
pub fn is_registered(&self, path: &Path) -> bool
Checks if the path is registered in the resource registry.
Sourcepub async fn scan(
resource_io: Arc<dyn ResourceIo>,
loaders: Arc<Mutex<RawMutex, ResourceLoadersContainer>>,
root: impl AsRef<Path>,
excluded_folders: HashSet<PathBuf, BuildHasherDefault<FxHasher>>,
) -> BTreeMap<Uuid, PathBuf>
pub async fn scan( resource_io: Arc<dyn ResourceIo>, loaders: Arc<Mutex<RawMutex, ResourceLoadersContainer>>, root: impl AsRef<Path>, excluded_folders: HashSet<PathBuf, BuildHasherDefault<FxHasher>>, ) -> BTreeMap<Uuid, PathBuf>
Searches for supported resources starting from the given path and builds a mapping UUID -> Path.
If a supported resource does not have a metadata file besides it, this method will automatically
create the metadata file with a new UUID and add the resource to the registry.
This method does not load any resource, instead it checks extension of every file in the given directory, and if there’s a loader for it, “remember” the resource.