pub trait WavePosition: OffsetPosition {
type Counter: WaveOffsetCounter<Offset = Self::Offset>;
}Expand description
A WavePosition is like an OffsetPosition but it also has a counter type
that the wave propagator can use to keep count of how many possible matching
patterns are available from each Offset.
Required Associated Types
Sourcetype Counter: WaveOffsetCounter<Offset = Self::Offset>
type Counter: WaveOffsetCounter<Offset = Self::Offset>
The type that holds count of patterns in each direction.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.