Track is responsible in animating a property of a single scene node. See Track docs for more info.
Structs
- Track
- Track is responsible in animating a property of a single scene node. The track consists up to 4 parametric curves that contains the actual property data. Parametric curves allows the engine to perform various interpolations between key values.
- Track
Binding - Track binding contains a handle to a target object that will be animated by an animation track. Additionally, the binding could be disabled to temporarily prevent animation from affecting the target.