Graph utilities and common algorithms.
Modules
Structs
- Graph
Traverse Iterator - Iterator that traverses tree in depth and returns shared references to nodes.
- Link
Scheme - Node
Handle Map - A
OriginalHandle -> CopyHandlemap. It is used to map handles to nodes after copying.
Enums
Traits
- Abstract
Scene Graph - Abstract
Scene Node - Base
Scene Graph - BaseSceneGraph is a dyn-compatible trait for all scene graphs to implement.
Methods that would not be dyn-compatible are available through the
SceneGraphtrait. - Prefab
Data - Scene
Graph - SceneGraph is a non-dyn-compatible trait for all scene graphs to implement.
To use a scene graph as a dyn object, use
dyn BaseSceneGraphbecauseBaseSceneGraphis dyn-compatible. - Scene
Graph Node