pub enum FieldKind {
Show 50 variants
Bool(bool),
U8(u8),
I8(i8),
U16(u16),
I16(i16),
U32(u32),
I32(i32),
U64(u64),
I64(i64),
F32(f32),
F64(f64),
UnitQuaternion(Unit<Quaternion<f32>>),
Matrix4(Matrix<f32, Const<4>, Const<4>, ArrayStorage<f32, 4, 4>>),
BinaryBlob(Vec<u8>),
Matrix3(Matrix<f32, Const<3>, Const<3>, ArrayStorage<f32, 3, 3>>),
Uuid(Uuid),
UnitComplex(Unit<Complex<f32>>),
PodArray {
type_id: u8,
element_size: u32,
bytes: Vec<u8>,
},
Matrix2(Matrix<f32, Const<2>, Const<2>, ArrayStorage<f32, 2, 2>>),
Vector2F32(Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>),
Vector3F32(Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>),
Vector4F32(Matrix<f32, Const<4>, Const<1>, ArrayStorage<f32, 4, 1>>),
Vector2F64(Matrix<f64, Const<2>, Const<1>, ArrayStorage<f64, 2, 1>>),
Vector3F64(Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>),
Vector4F64(Matrix<f64, Const<4>, Const<1>, ArrayStorage<f64, 4, 1>>),
Vector2U8(Matrix<u8, Const<2>, Const<1>, ArrayStorage<u8, 2, 1>>),
Vector3U8(Matrix<u8, Const<3>, Const<1>, ArrayStorage<u8, 3, 1>>),
Vector4U8(Matrix<u8, Const<4>, Const<1>, ArrayStorage<u8, 4, 1>>),
Vector2I8(Matrix<i8, Const<2>, Const<1>, ArrayStorage<i8, 2, 1>>),
Vector3I8(Matrix<i8, Const<3>, Const<1>, ArrayStorage<i8, 3, 1>>),
Vector4I8(Matrix<i8, Const<4>, Const<1>, ArrayStorage<i8, 4, 1>>),
Vector2U16(Matrix<u16, Const<2>, Const<1>, ArrayStorage<u16, 2, 1>>),
Vector3U16(Matrix<u16, Const<3>, Const<1>, ArrayStorage<u16, 3, 1>>),
Vector4U16(Matrix<u16, Const<4>, Const<1>, ArrayStorage<u16, 4, 1>>),
Vector2I16(Matrix<i16, Const<2>, Const<1>, ArrayStorage<i16, 2, 1>>),
Vector3I16(Matrix<i16, Const<3>, Const<1>, ArrayStorage<i16, 3, 1>>),
Vector4I16(Matrix<i16, Const<4>, Const<1>, ArrayStorage<i16, 4, 1>>),
Vector2U32(Matrix<u32, Const<2>, Const<1>, ArrayStorage<u32, 2, 1>>),
Vector3U32(Matrix<u32, Const<3>, Const<1>, ArrayStorage<u32, 3, 1>>),
Vector4U32(Matrix<u32, Const<4>, Const<1>, ArrayStorage<u32, 4, 1>>),
Vector2I32(Matrix<i32, Const<2>, Const<1>, ArrayStorage<i32, 2, 1>>),
Vector3I32(Matrix<i32, Const<3>, Const<1>, ArrayStorage<i32, 3, 1>>),
Vector4I32(Matrix<i32, Const<4>, Const<1>, ArrayStorage<i32, 4, 1>>),
Vector2U64(Matrix<u64, Const<2>, Const<1>, ArrayStorage<u64, 2, 1>>),
Vector3U64(Matrix<u64, Const<3>, Const<1>, ArrayStorage<u64, 3, 1>>),
Vector4U64(Matrix<u64, Const<4>, Const<1>, ArrayStorage<u64, 4, 1>>),
Vector2I64(Matrix<i64, Const<2>, Const<1>, ArrayStorage<i64, 2, 1>>),
Vector3I64(Matrix<i64, Const<3>, Const<1>, ArrayStorage<i64, 3, 1>>),
Vector4I64(Matrix<i64, Const<4>, Const<1>, ArrayStorage<i64, 4, 1>>),
String(String),
}Expand description
The internal data format of crate::visitor::Visitor. Fields are limited to being one of these types.
This means that all crate::visitor::Visit values must be built from some assortment
of these types.
Fields can be accessed from a visitor using crate::visitor::Visit::visit on a variable with the
same type as the field.
Variants
Bool(bool)
Boolean value.
U8(u8)
u8 value.
I8(i8)
i8 value.
U16(u16)
u16 value.
I16(i16)
i16 value.
U32(u32)
u32 value.
I32(i32)
i32 value.
U64(u64)
u64 value.
I64(i64)
i64 value.
F32(f32)
f32 value.
F64(f64)
f64 value.
UnitQuaternion(Unit<Quaternion<f32>>)
Unit quaternion.
Matrix4(Matrix<f32, Const<4>, Const<4>, ArrayStorage<f32, 4, 4>>)
4x4 f32 matrix.
BinaryBlob(Vec<u8>)
A representation of some Vec<T> where T must be Copy.
It is mostly used to store the bytes of string types.
Matrix3(Matrix<f32, Const<3>, Const<3>, ArrayStorage<f32, 3, 3>>)
3x3 f32 matrix.
Uuid(Uuid)
Unique id.
UnitComplex(Unit<Complex<f32>>)
A complex number.
PodArray
A representation for arrays of crate::visitor::pod::Pod types as a Vec<u8>.
Fields
type_id: u8A code to identify the Pod type of the elements of the array.
Taken from crate::visitor::pod::Pod::type_id.
Matrix2(Matrix<f32, Const<2>, Const<2>, ArrayStorage<f32, 2, 2>>)
2x2 f32 matrix.
Vector2F32(Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>)
2D f32 vector.
Vector3F32(Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>)
3D f32 vector.
Vector4F32(Matrix<f32, Const<4>, Const<1>, ArrayStorage<f32, 4, 1>>)
4D f32 vector.
Vector2F64(Matrix<f64, Const<2>, Const<1>, ArrayStorage<f64, 2, 1>>)
2D f64 vector.
Vector3F64(Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>)
3D f64 vector.
Vector4F64(Matrix<f64, Const<4>, Const<1>, ArrayStorage<f64, 4, 1>>)
4D f64 vector.
Vector2U8(Matrix<u8, Const<2>, Const<1>, ArrayStorage<u8, 2, 1>>)
2D u8 vector.
Vector3U8(Matrix<u8, Const<3>, Const<1>, ArrayStorage<u8, 3, 1>>)
3D u8 vector.
Vector4U8(Matrix<u8, Const<4>, Const<1>, ArrayStorage<u8, 4, 1>>)
4D u8 vector.
Vector2I8(Matrix<i8, Const<2>, Const<1>, ArrayStorage<i8, 2, 1>>)
2D i8 vector.
Vector3I8(Matrix<i8, Const<3>, Const<1>, ArrayStorage<i8, 3, 1>>)
3D i8 vector.
Vector4I8(Matrix<i8, Const<4>, Const<1>, ArrayStorage<i8, 4, 1>>)
4D i8 vector.
Vector2U16(Matrix<u16, Const<2>, Const<1>, ArrayStorage<u16, 2, 1>>)
2D u16 vector.
Vector3U16(Matrix<u16, Const<3>, Const<1>, ArrayStorage<u16, 3, 1>>)
3D u16 vector.
Vector4U16(Matrix<u16, Const<4>, Const<1>, ArrayStorage<u16, 4, 1>>)
4D u16 vector.
Vector2I16(Matrix<i16, Const<2>, Const<1>, ArrayStorage<i16, 2, 1>>)
2D i16 vector.
Vector3I16(Matrix<i16, Const<3>, Const<1>, ArrayStorage<i16, 3, 1>>)
3D i16 vector.
Vector4I16(Matrix<i16, Const<4>, Const<1>, ArrayStorage<i16, 4, 1>>)
4D i16 vector.
Vector2U32(Matrix<u32, Const<2>, Const<1>, ArrayStorage<u32, 2, 1>>)
2D u32 vector.
Vector3U32(Matrix<u32, Const<3>, Const<1>, ArrayStorage<u32, 3, 1>>)
3D u32 vector.
Vector4U32(Matrix<u32, Const<4>, Const<1>, ArrayStorage<u32, 4, 1>>)
4D u32 vector.
Vector2I32(Matrix<i32, Const<2>, Const<1>, ArrayStorage<i32, 2, 1>>)
2D i32 vector.
Vector3I32(Matrix<i32, Const<3>, Const<1>, ArrayStorage<i32, 3, 1>>)
3D i32 vector.
Vector4I32(Matrix<i32, Const<4>, Const<1>, ArrayStorage<i32, 4, 1>>)
4D i32 vector.
Vector2U64(Matrix<u64, Const<2>, Const<1>, ArrayStorage<u64, 2, 1>>)
2D u64 vector.
Vector3U64(Matrix<u64, Const<3>, Const<1>, ArrayStorage<u64, 3, 1>>)
3D u64 vector.
Vector4U64(Matrix<u64, Const<4>, Const<1>, ArrayStorage<u64, 4, 1>>)
4D u64 vector.
Vector2I64(Matrix<i64, Const<2>, Const<1>, ArrayStorage<i64, 2, 1>>)
2D i64 vector.
Vector3I64(Matrix<i64, Const<3>, Const<1>, ArrayStorage<i64, 3, 1>>)
3D i64 vector.
Vector4I64(Matrix<i64, Const<4>, Const<1>, ArrayStorage<i64, 4, 1>>)
4D i64 vector.
String(String)
A unicode string.