pub trait GpuShaderTrait: GpuShaderAsAny { }Expand description
A trait for whatever objects a graphics server is using to represent shaders.
There are no methods because all interactions with programs are done through the server,
such as with crate::server::GraphicsServer::create_shader.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".