pub fn image_3d_size_bytes( pixel_kind: PixelKind, width: usize, height: usize, depth: usize, ) -> usize
Calculates size in bytes of a volume texture using the given size of the texture and its pixel kind.