Module uniform

Module uniform 

Uniform buffer is a special byte storage that ensures correct data alignment suitable for GPU. Current implementation supports std140 data layout scheme.

Structs

UniformBuffer
Uniform buffer is a special byte storage that ensures correct data alignment suitable for GPU. Current implementation supports std140 data layout scheme.

Traits

ByteStorage
A trait for any storage suitable to store bytes for uniforms.
Std140
A trait for entities that supports std140 data layout.

Type Aliases

DynamicUniformBuffer
A uniform buffer backed by a dynamic array.
StaticUniformBuffer
A uniform buffer backed by an array of fixed size.