Structs
- GlGraphics
Server GlGraphicsServerimplements theGraphicsServertrait using theglowcrate.glowis “GL on Whatever: a set of bindings to run GL anywhere (Open GL, OpenGL ES, and WebGL) and avoid target-specific code.”
Enums
- Frame
Buffer Binding Point - A frame buffer can be bound for reading, writing, or both.
- GlKind
- Indicator of whether we are using the embedded version of OpenGL.