The Border widget provides a stylized, static border around its child widget. See Border docs for more info and
usage examples.
Structs
- Border
- The Border widget provides a stylized, static border around its child widget. Below is an example of creating a 1 pixel thick border around a button widget:
- Border
Builder - Border builder.
Enums
- Border
Message - Supported border-specific messages.