Checkbox is a UI widget that have three states - Checked, Unchecked and Undefined. In most cases, it is used
only with two values which fit in bool type. Third, undefined, state is used for specific situations when your
data have such state. See CheckBox docs for more info and usage examples.
Structs
- Check
Box - Checkbox is a UI widget that have three states -
Checked,UncheckedandUndefined. In most cases, it is used only with two values which fit inbooltype. Third, undefined, state is used for specific situations when your data have such state. - Check
BoxBuilder - Check box builder creates
CheckBoxinstances and adds them to the user interface.
Enums
- Check
BoxMessage - A set of possible check box messages.