A visual element that is used to highlight standard states of interactive widgets. It has “pressed”, “hover”,
“selected”, “normal” appearances. See Decorator docs for more info and usage examples.
Structs
- Decorator
- A visual element that is used to highlight standard states of interactive widgets. It has “pressed”, “hover”, “selected”, “normal” appearances (only one can be active at a time):
- Decorator
Builder - Creates
Decoratorwidget instances and adds them to the user interface.
Enums
- Decorator
Message - A set of messages that is used to modify
Decoratorwidgets state.