input box is a window that is used to show standard confirmation/information dialogues, for example, closing a document with
unsaved changes. It has a title, some text, and a fixed set of buttons (Yes, No, Cancel in different combinations). See
InputBox docs for more info and usage examples.
Structs
- Input
Box - Input box is a window that is used to show standard input dialogues, for example, a rename dialog.
It has a title, some description text, input field and
Ok+Cancelbuttons. - Input
BoxBuilder - Creates
InputBoxwidgets and adds them to the user interface.
Enums
- Input
BoxMessage - A set of messages that can be used to communicate with input boxes.
- Input
BoxResult - A set of possible reasons why a input box was closed.