A set of editors for hot keys and key bindings. See HotKeyEditor and KeyBindingEditor widget’s docs
for more info and usage examples.
Structs
- HotKey
Editor - Hot key editor is used to provide a unified way of editing an arbitrary combination of modifiers keyboard keys (such
as Ctrl, Shift, Alt) with any other key. It could be used, if you need a simple way to add an editor for
HotKey. - HotKey
Editor Builder - Hot key editor builder creates
HotKeyEditorwidget instances and adds them to the user interface. - KeyBinding
Editor - Key binding editor is used to provide a unified way of setting a key binding.
- KeyBinding
Editor Builder - Key binding editor builder is used to create
KeyBindingEditorwidgets and add them to the user interface.
Enums
- HotKey
- Hot key is a combination of a key code with an arbitrary set of keyboard modifiers (such as Ctrl, Shift, Alt keys).
- HotKey
Editor Message - A set of messages, that is used to alternate the state of
HotKeyEditorwidget or to listen to its changes. - KeyBinding
- Key binding is a simplified version of
HotKeythat consists of a single physical key code. It is usually used for “unconditional” (independent of modifier keys state) triggering of some action. - KeyBinding
Editor Message - A set of messages, that is used to modify
KeyBindingEditorstate or to listen to its changes.