List view is used to display lists with arbitrary items. It supports single-selection, and by default, it stacks the items vertically.
Structs
- List
View - List view is used to display lists with arbitrary items. It supports multiple selection and by default, it stacks the items vertically (this can be changed by providing a custom panel for the items, see the section below).
- List
View Builder - List view builder is used to create
ListViewwidget instances and add them to a user interface. - List
View Item - A wrapper for list view items, that is used to add selection functionality to arbitrary items.
Enums
- List
View Message - A set of messages that can be used to modify/fetch the state of a
ListViewwidget at runtime.