Scroll bar is used to represent a value on a finite range. It has a thumb that shows the
current value of the bar. See ScrollBar docs for more info and usage examples.
Structs
- Scroll
Bar - Scroll bar is used to represent a value on a finite range. It has a thumb that shows the current value
on the bar. Usually it is used in pair with
crate::scroll_panel::ScrollPanelto create something likecrate::scroll_viewer::ScrollViewerwidget. However, it could also be used to create sliders to show some value that lies within some range. - Scroll
BarBuilder - Scroll bar widget is used to create
ScrollBarwidget instances and add them to the user interface.
Enums
- Scroll
BarMessage - A set of messages that can be accepted by
ScrollBarwidget.