Selector is a simple container widget that allows selecting an item from a fixed set of items.
See Selector docs for more info.
Structs
- Selector
- Selector is a simple container widget that allows selecting an item from a fixed set of items. Selector widget shows the currently selected item at the center and two buttons on the sides that allows selecting either the previous or the next item.
- Selector
Builder - Creates instances of
Selectorwidgets.
Enums
- Selector
Message - A set of messages that is used by
Selectorwidget.