UUID editor is used to show an arbitrary UUID and give an ability to generate a new value. See UuidEditor docs for
more info and usage examples.
Structs
- Uuid
Editor - UUID editor is used to show an arbitrary UUID and give an ability to generate a new value. It is widely used in
crate::inspector::Inspectorto show and edit UUIDs. - Uuid
Editor Builder - Creates
UuidEditorwidgets and add them to the user interface.
Enums
- Uuid
Editor Message - A set of messages that is used to fetch or modify values of
UuidEditorwidgets.