macro_rules! dispatch_behavior_variants {
($type_name:ident, $context:ty, $($variants:ident),*) => { ... };
}Expand description
Implements Behavior trait for the given enumeration and dispatches tick call of every
specified variant. This macro is used mostly to reduce boilerplate code