pub type UiLoaderOutput = LoaderOutput<UserInterface>;Expand description
Alias for LoaderOutput<UserInterface>
Aliased Type
pub struct UiLoaderOutput {
pub payload: UserInterface,
pub path: PathBuf,
pub data: Vec<u8>,
}Fields
payload: UserInterfaceThe object produced by the loader.
path: PathBufA path of the source file.
data: Vec<u8>A raw data from which the loader output was created from. Usually it is just a content of the source file.