Structs
Enums
Statics
Functions
- decode_
base64 - import_
images - import_
materials - Extract a list of MaterialResource from the give glTF document, if that document contains any. The resulting list of materials is guaranteed to be the same length as the list of materials in the document so that an index into the document’s list of materials will be the same as the index of the matching MaterialResource in the returned list. This is important since the glTF document refers to materials by index.
- import_
textures