Everything related to textures. See fyrox_texture crate docs for more info.
Modules
- loader
- Texture loader.
Structs
- PLACEHOLDER
- Placeholder texture.
- Texture
- Actual texture data.
- Texture
Bytes - Data storage of a texture.
- Texture
Data RefMut - A special reference holder that provides mutable access to content of the texture and automatically calculates hash of the data in its destructor.
- Texture
Import Options - Allows you to define a set of parameters for a texture resource.
Enums
- Compression
Options - Texture compression options.
- MipFilter
- A filter for mip-map generation.
- Texture
Error - An error that may occur during texture operations.
- Texture
Kind - Texture kind.
- Texture
Magnification Filter - The texture magnification function is used when the pixel being textured maps to an area less than or equal to one texture element.
- Texture
Minification Filter - The texture minifying function is used whenever the pixel being textured maps to an area greater than one texture element.
- Texture
Pixel Kind - Texture kind defines pixel format of texture.
- Texture
Wrap Mode - Defines a law of texture coordinate modification.
Traits
- Texture
Resource Extension - Extension trait for texture resources.
Type Aliases
- Texture
Resource - Type alias for texture resources.