Contains all methods and structures to create and manage cameras. See Camera docs for more info.
Structs
- Camera
- Camera allows you to see world from specific point in world. You must have at least one camera in your scene to see anything.
- Camera
Builder - Camera builder is used to create new camera in declarative manner. This is typical implementation of Builder pattern.
- Color
Grading Lut - Color grading look up table (LUT). Color grading is used to modify color space of the rendered frame; it maps one color space to another. It is widely used effect in games, you’ve probably noticed either “warmness” or “coldness” in colors in various scenes in games - this is achieved by color grading.
- Orthographic
Projection - Parallel projection. Object’s size won’t be affected by distance from the viewer, it can be used for 2D games.
- Perspective
Projection - Perspective projection make parallel lines to converge at some point. Objects will be smaller with increasing distance. This the projection type “used” by human eyes, photographic lens and it looks most realistic.
Enums
- Color
Grading LutCreation Error - All possible error that may occur during color grading look-up table creation.
- Exposure
- Exposure is a parameter that describes how many light should be collected for one frame. The higher the value, the more brighter the final frame will be and vice versa.
- FitParameters
- A set of camera fitting parameters for different projection modes. You should take these parameters
and modify camera position and projection accordingly. In case of perspective projection all you need
to do is to set new world-space position of the camera. In cae of orthographic projection, do previous
step and also modify vertical size of orthographic projection (see
OrthographicProjectionfor more info). - Projection
- A method of projection. Different projection types suitable for different purposes: