Collider is a geometric entity that can be attached to a rigid body to allow participate it participate in contact generation, collision response and proximity queries.
Structs
- Ball
Shape - Ball is an idea sphere shape defined by a single parameters - its radius.
- BitMask
- A set of bits used for pairwise collision filtering.
- Capsule
Shape - Arbitrary capsule shape defined by 2 points (which forms axis) and a radius.
- Collider
- Collider is a geometric entity that can be attached to a rigid body to allow participate it participate in contact generation, collision response and proximity queries.
- Collider
Builder - Collider builder allows you to build a collider node in declarative mannner.
- Cone
Shape - Cone shape aligned in Y axis.
- Convex
Polyhedron Shape - Arbitrary convex polyhedron shape.
- Cuboid
Shape - Cuboid shape (box).
- Cylinder
Shape - Cylinder shape aligned in Y axis.
- Geometry
Source - Geometry source for colliders with complex geometry.
- Heightfield
Shape - Arbitrary height field shape.
- Interaction
Groups - Pairwise filtering using bit masks.
- Query
Filter Flags - Flags for excluding whole sets of colliders from a scene query.
- Segment
Shape - Arbitrary segment shape defined by two points.
- Triangle
Shape - Arbitrary triangle shape.
- Trimesh
Shape - Arbitrary triangle mesh shape.
Enums
- Collider
Shape - Possible collider shapes.
- TOIStatus
- The status of the time-of-impact computation algorithm.