Scene physics module.
Structs
- Contact
Data - Data of the contact.
- Contact
Manifold - A contact manifold between two colliders.
- Contact
Pair - Contact info for pair of colliders.
- Intersection
- A ray intersection result.
- Intersection
Pair - Intersection info for pair of colliders.
- Physics
World - Physics world is responsible for physics simulation in the engine. There is a very few public methods, mostly for ray casting. You should add physical entities using scene graph nodes, such as RigidBody, Collider, Joint.
- Query
Filter - A filter tha describes what collider should be included or excluded from a scene query.
- RayCast
Options - A set of options for the ray cast.
- TOI
- The result of a time-of-impact (TOI) computation.
Enums
- Shape
Type - Enum representing the type of a shape.
- Typed
Shape - Enum representing the shape with its actual type
Traits
- Query
Results Storage - A trait for ray cast results storage. It has two implementations: Vec and ArrayVec. Latter is needed for the cases where you need to avoid runtime memory allocations and do everything on stack.
- Shape
- Trait implemented by shapes usable by Rapier.