Contains all structures and methods to create and manage mesh scene graph nodes. See Mesh docs for more info
and usage examples.
Modules
- buffer
- Vertex buffer with dynamic layout. See
VertexBufferdocs for more info and usage examples. - surface
- Surface is a set of triangles with a single material. Such arrangement makes GPU rendering very efficient.
See
Surfacedocs for more info and usage examples. - vertex
- Contains most common vertex formats and their layouts.
Structs
- Mesh
- Mesh is a 3D model, each mesh split into multiple surfaces, each surface represents a patch of the mesh with a single material
assigned to each face. See
Surfacedocs for more info. - Mesh
Builder - Mesh builder allows you to construct mesh in declarative manner.
Enums
- Batching
Mode - Batching mode defines how the mesh data will be grouped before rendering.
- Render
Path - Defines a path that should be used to render a mesh.