pub type SurfaceResource = Resource<SurfaceData>;Expand description
Surface shared data is a vertex and index buffer that can be shared across multiple objects. This is very useful memory optimization - you create a single data storage for a surface and then share it with any instance count you want. Memory usage does not increase with instance count in this case.
Aliased Type
pub struct SurfaceResource { /* private fields */ }Trait Implementations
Sourceimpl SurfaceResourceExtension for SurfaceResource
impl SurfaceResourceExtension for SurfaceResource
Sourcefn deep_clone(&self) -> Self
fn deep_clone(&self) -> Self
Creates a full copy of the internals of the data and creates a new surface resource of it.