Rigid body is a physics entity that responsible for the dynamics and kinematics of the solid.
Common problems
Q: Rigid body is “stuck”.
A: Most likely the rigid body is “sleeping”, in this case it must be activated manually, it is
most common problem with rigid bodies that controlled manually from code. They must be activated
using RigidBody::wake_up. By default any external action does not wakes up rigid body.
You can also explicitly tell to rigid body that it cannot sleep, by calling
RigidBody::set_can_sleep with false value.
Structs
- Rigid
Body - Rigid body is a physics entity that responsible for the dynamics and kinematics of the solid. Use this node when you need to simulate real-world physics in your game.
- Rigid
Body Builder - Allows you to create rigid body in declarative manner.
Enums
- Rigid
Body Type - A set of possible types of rigid body.