Skybox is a huge box around a camera. See SkyBox docs for more info.
Structs
- SkyBox
- Skybox is a huge box around a camera. Each face has its own texture, when textures are properly made, there is no seams and you get good decoration which contains static skies and/or some other objects (mountains, buildings, etc.). Usually skyboxes used in outdoor scenes, however real use of it limited only by your imagination. Skybox will be drawn first, none of objects could be drawn before skybox.
- SkyBox
Builder - SkyBox builder is used to create new skybox in declarative manner.
Enums
- SkyBox
Error - An error that may occur during skybox creation.
- SkyBox
Kind - A fixed set of possible sky boxes, that can be selected when building
super::camera::Camerascene node.