pub struct HrirSphere { /* private fields */ }Expand description
HRIR (Head-Related Impulse Response) spheres is a 3d mesh whose points contains impulse responses for left and right ears. It is used for interpolation of impulse responses.
Implementations
Sourceimpl HrirSphere
impl HrirSphere
Sourcepub fn from_file<P>(
path: P,
device_sample_rate: u32,
) -> Result<HrirSphere, HrtfError>
pub fn from_file<P>( path: P, device_sample_rate: u32, ) -> Result<HrirSphere, HrtfError>
Tries to load a sphere from a file.
Sourcepub fn new<R>(
reader: R,
device_sample_rate: u32,
) -> Result<HrirSphere, HrtfError>where
R: Read,
pub fn new<R>(
reader: R,
device_sample_rate: u32,
) -> Result<HrirSphere, HrtfError>where
R: Read,
Loads HRIR sphere from given source.
Coordinate system
Hrtf spheres made in right-handed coordinate system. This fact can give weird positioning issues if your application uses left-handed coordinate system. However this can be fixed very easily: iterate over every point and invert X coordinate of it.
Sample rate
HRIR spheres from this base recorded in 44100 Hz sample rate. If your output device uses different sample rate, you have to resample initial set of .wav files and regenerate HRIR spheres. There could
Sourcepub fn transform(&mut self, matrix: &[f32; 16])
pub fn transform(&mut self, matrix: &[f32; 16])
Applies specified transform to each point in sphere. Can be used to rotate or scale sphere. Transform shouldn’t have translation part, otherwise result of bilinear sampling is undefined.
Sourcepub fn points_mut(&mut self) -> &mut [HrirPoint]
pub fn points_mut(&mut self) -> &mut [HrirPoint]
Returns mutable reference to sphere points array.