Contains all structures and methods to create and manage sprites.
For more info see Sprite.
Structs
- Sprite
- Sprite is a billboard which always faces towards the camera. It can be used as a “model” for bullets, and so on.
- Sprite
Builder - Sprite builder allows you to construct sprite in declarative manner. This is typical implementation of Builder pattern.
- Sprite
Vertex - A vertex for sprites.