pub struct TileMapBrush {
pub tile_set: Option<TileSetResource>,
pub pages: TileGridMap<TileMapBrushPage>,
pub macros: BrushMacroInstanceList,
pub change_flag: ChangeFlag,
}Expand description
Tile map brush is a set of tiles arranged in arbitrary shape, that can be used to draw on a tile map.
Fields
tile_set: Option<TileSetResource>The tile set used by this brush. This must match the tile set of any tile map that this brush is used to edit.
pages: TileGridMap<TileMapBrushPage>The set of pages contained in the brush Each page is associated with 2D coordinates within a palette of brush pages. This allows pages to be selected much like tiles are selected, and it allows users to customize the organization of pages.
macros: BrushMacroInstanceListUntyped data stored in this brush for use by some macro.
change_flag: ChangeFlagA record of whether the brush has changed since last time it was saved.
Implementations
Sourceimpl TileMapBrush
impl TileMapBrush
Sourceimpl TileMapBrush
impl TileMapBrush
Sourcepub fn block_until_tile_set_is_loaded(&self) -> bool
pub fn block_until_tile_set_is_loaded(&self) -> bool
Return true after blocking to wait for the brush’s tile set to load, if the tile set loads successfully, or if the tile set has no brush. Return false if any error occurs while trying to load the tile set.
Sourcepub fn tile_set(&self) -> Option<TileSetResource>
pub fn tile_set(&self) -> Option<TileSetResource>
Return the tile set for this brush, blocking if the tile set is not yet loaded. None is returned if this brush has no tile set or the tile set fails to load.
Sourcepub fn has_tile_at(&self, page: Vector2<i32>, tile: Vector2<i32>) -> bool
pub fn has_tile_at(&self, page: Vector2<i32>, tile: Vector2<i32>) -> bool
True if there is a tile at the given position.
Sourcepub fn has_page_at(&self, page: Vector2<i32>) -> bool
pub fn has_page_at(&self, page: Vector2<i32>) -> bool
True if there is a page at the given position.
Sourcepub fn tile_redirect(
&self,
handle: TileDefinitionHandle,
) -> Option<TileDefinitionHandle>
pub fn tile_redirect( &self, handle: TileDefinitionHandle, ) -> Option<TileDefinitionHandle>
The handle stored at the given position.
Sourcepub fn pages_bounds(&self) -> OptionTileRect
pub fn pages_bounds(&self) -> OptionTileRect
Returns bounding rectangle of pages in grid coordinates.
Sourcepub fn page_icon(&self, page: Vector2<i32>) -> Option<TileDefinitionHandle>
pub fn page_icon(&self, page: Vector2<i32>) -> Option<TileDefinitionHandle>
The handle of the tile that represents the page at the given position.
Sourcepub fn tiles_bounds(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
) -> OptionTileRect
pub fn tiles_bounds( &self, stage: TilePaletteStage, page: Vector2<i32>, ) -> OptionTileRect
The bounds of the tiles on the given page.
Sourcepub fn find_tile_at_position(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
position: Vector2<i32>,
) -> Option<TileDefinitionHandle>
pub fn find_tile_at_position( &self, stage: TilePaletteStage, page: Vector2<i32>, position: Vector2<i32>, ) -> Option<TileDefinitionHandle>
The handle of the tile at the given position, either the icon of a page or the tile stored at that position in the brush.
Sourcepub fn get_tiles<I: Iterator<Item = Vector2<i32>>>(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
iter: I,
tiles: &mut Tiles,
)
pub fn get_tiles<I: Iterator<Item = Vector2<i32>>>( &self, stage: TilePaletteStage, page: Vector2<i32>, iter: I, tiles: &mut Tiles, )
The tile definition handles of the tiles at the given positions on the given page.
Sourcepub fn is_missing_tile_set(&self) -> bool
pub fn is_missing_tile_set(&self) -> bool
Return true if this brush has no tile set.
Sourcepub fn palette_render_loop<F>(
&self,
stage: TilePaletteStage,
page: Vector2<i32>,
func: F,
)
pub fn palette_render_loop<F>( &self, stage: TilePaletteStage, page: Vector2<i32>, func: F, )
Loops through the tiles of the given page and finds the render data for each tile in the tile set, then passes it to the given function.
Sourcepub fn get_tile_render_data(
&self,
position: ResourceTilePosition,
) -> Option<TileRenderData>
pub fn get_tile_render_data( &self, position: ResourceTilePosition, ) -> Option<TileRenderData>
Return the TileRenderData needed to render the tile at the given position on the given page.
If there is no tile at that position or the tile set is missing or not loaded, then None is returned.
If there is a tile and a tile set, but the handle of the tile does not exist in the tile set,
then the rendering data for an error tile is returned using TileRenderData::missing_tile().
Sourcepub fn redirect_handle(
&self,
position: ResourceTilePosition,
) -> Option<TileDefinitionHandle>
pub fn redirect_handle( &self, position: ResourceTilePosition, ) -> Option<TileDefinitionHandle>
The tiles of a brush are references to tiles in the tile set. This method converts positions within the brush into the handle that points to the corresponding tile definition within the tile set. If this brush does not contain a reference at the given position, then None is returned.
Sourcepub fn stamp_element(
&self,
position: ResourceTilePosition,
) -> Option<StampElement>
pub fn stamp_element( &self, position: ResourceTilePosition, ) -> Option<StampElement>
The stamp element for the given position, if the tile in that cell is used
to create a stamp. The StampElement::handle refers to the location of the tile within the
tile set, while the StampElement::source refers to the location of the tile within
the brush.
Sourcepub fn get_tile_bounds(
&self,
position: ResourceTilePosition,
) -> Option<TileMaterialBounds>
pub fn get_tile_bounds( &self, position: ResourceTilePosition, ) -> Option<TileMaterialBounds>
The TileMaterialBounds taken from the tile set for the tile in the brush at the given position.
Sourcepub fn is_free_at(&self, position: ResourceTilePosition) -> bool
pub fn is_free_at(&self, position: ResourceTilePosition) -> bool
Returns true if the brush is unoccupied at the given position.
Sourcepub async fn from_file(
path: &Path,
resource_manager: ResourceManager,
io: &dyn ResourceIo,
) -> Result<Self, TileMapBrushResourceError>
pub async fn from_file( path: &Path, resource_manager: ResourceManager, io: &dyn ResourceIo, ) -> Result<Self, TileMapBrushResourceError>
Load a tile map brush resource from the specific file path.