pub struct TileSetPage {
pub icon: TileDefinitionHandle,
pub source: TileSetPageSource,
}Expand description
A tile set can contain multiple pages of tiles, and each page may have its own independent source of tile data.
Fields
icon: TileDefinitionHandleThe tile that represents this page in the editor
source: TileSetPageSourceThe source of the page’s data.
Implementations
Sourceimpl TileSetPage
impl TileSetPage
Sourceimpl TileSetPage
impl TileSetPage
Sourcepub fn is_material(&self) -> bool
pub fn is_material(&self) -> bool
True if this page is a material page.
Sourcepub fn is_freeform(&self) -> bool
pub fn is_freeform(&self) -> bool
True if this page is a freeform tile page.
Sourcepub fn is_transform_set(&self) -> bool
pub fn is_transform_set(&self) -> bool
True if this page contains tile transform groups.
Sourcepub fn is_animation(&self) -> bool
pub fn is_animation(&self) -> bool
True if this page contains tile transform groups.
Sourcepub fn has_tile_at(&self, position: Vector2<i32>) -> bool
pub fn has_tile_at(&self, position: Vector2<i32>) -> bool
True if a tile exists at the given position in this page.
Sourcepub fn get_bounds(&self) -> OptionTileRect
pub fn get_bounds(&self) -> OptionTileRect
The rect that contains all the tiles of this page.
Sourcepub fn swap_tile(&mut self, position: Vector2<i32>, update: &mut TileDataUpdate)
pub fn swap_tile(&mut self, position: Vector2<i32>, update: &mut TileDataUpdate)
Change this tile set according to the specifications in update, and change update so
that it would refers the change to this tile set, if it were applied again at the same position.
Sourcepub fn swap_all_values_for_property(
&mut self,
page: Vector2<i32>,
property_id: Uuid,
values: &mut FxHashMap<TileDefinitionHandle, TileSetPropertyValue>,
)
pub fn swap_all_values_for_property( &mut self, page: Vector2<i32>, property_id: Uuid, values: &mut FxHashMap<TileDefinitionHandle, TileSetPropertyValue>, )
Take all the values for the property with the given id, remove them from the page, and put them into the given hash map. At the same time, take all the values from the given hash map and put them into the page.
Sourcepub fn swap_all_values_for_collider(
&mut self,
page: Vector2<i32>,
collider_id: Uuid,
values: &mut FxHashMap<TileDefinitionHandle, TileCollider>,
)
pub fn swap_all_values_for_collider( &mut self, page: Vector2<i32>, collider_id: Uuid, values: &mut FxHashMap<TileDefinitionHandle, TileCollider>, )
Take all the colliders for the given collider id, remove them from the page, and put them into the given hash map. At the same time, take all the colliders from the given hash map and put them into the page.